#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.EnterpriseOpenRuleInfo import EnterpriseOpenRuleInfo


class AlipayEbppInvoiceEnterpriseconsumeEnterpriseopenruleQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppInvoiceEnterpriseconsumeEnterpriseopenruleQueryResponse, self).__init__()
        self._enterprise_open_rule_info = None

    @property
    def enterprise_open_rule_info(self):
        return self._enterprise_open_rule_info

    @enterprise_open_rule_info.setter
    def enterprise_open_rule_info(self, value):
        if isinstance(value, EnterpriseOpenRuleInfo):
            self._enterprise_open_rule_info = value
        else:
            self._enterprise_open_rule_info = EnterpriseOpenRuleInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayEbppInvoiceEnterpriseconsumeEnterpriseopenruleQueryResponse, self).parse_response_content(response_content)
        if 'enterprise_open_rule_info' in response:
            self.enterprise_open_rule_info = response['enterprise_open_rule_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.DiscountDetailInfo import DiscountDetailInfo


class KoubeiTradeOrderAggregateConsultResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiTradeOrderAggregateConsultResponse, self).__init__()
        self._buyer_id = None
        self._buyer_id_type = None
        self._buyer_pay_amount = None
        self._create_time = None
        self._discount_detail_list = None
        self._gmt_payment_time = None
        self._merchant_discount_amount = None
        self._order_no = None
        self._order_status = None
        self._out_order_no = None
        self._pay_channel = None
        self._platform_discount_amount = None
        self._receipt_amount = None
        self._total_amount = None
        self._trade_no = None

    @property
    def buyer_id(self):
        return self._buyer_id

    @buyer_id.setter
    def buyer_id(self, value):
        self._buyer_id = value
    @property
    def buyer_id_type(self):
        return self._buyer_id_type

    @buyer_id_type.setter
    def buyer_id_type(self, value):
        self._buyer_id_type = value
    @property
    def buyer_pay_amount(self):
        return self._buyer_pay_amount

    @buyer_pay_amount.setter
    def buyer_pay_amount(self, value):
        self._buyer_pay_amount = value
    @property
    def create_time(self):
        return self._create_time

    @create_time.setter
    def create_time(self, value):
        self._create_time = value
    @property
    def discount_detail_list(self):
        return self._discount_detail_list

    @discount_detail_list.setter
    def discount_detail_list(self, value):
        if isinstance(value, DiscountDetailInfo):
            self._discount_detail_list = value
        else:
            self._discount_detail_list = DiscountDetailInfo.from_alipay_dict(value)
    @property
    def gmt_payment_time(self):
        return self._gmt_payment_time

    @gmt_payment_time.setter
    def gmt_payment_time(self, value):
        self._gmt_payment_time = value
    @property
    def merchant_discount_amount(self):
        return self._merchant_discount_amount

    @merchant_discount_amount.setter
    def merchant_discount_amount(self, value):
        self._merchant_discount_amount = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def pay_channel(self):
        return self._pay_channel

    @pay_channel.setter
    def pay_channel(self, value):
        self._pay_channel = value
    @property
    def platform_discount_amount(self):
        return self._platform_discount_amount

    @platform_discount_amount.setter
    def platform_discount_amount(self, value):
        self._platform_discount_amount = value
    @property
    def receipt_amount(self):
        return self._receipt_amount

    @receipt_amount.setter
    def receipt_amount(self, value):
        self._receipt_amount = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value

    def parse_response_content(self, response_content):
        response = super(KoubeiTradeOrderAggregateConsultResponse, self).parse_response_content(response_content)
        if 'buyer_id' in response:
            self.buyer_id = response['buyer_id']
        if 'buyer_id_type' in response:
            self.buyer_id_type = response['buyer_id_type']
        if 'buyer_pay_amount' in response:
            self.buyer_pay_amount = response['buyer_pay_amount']
        if 'create_time' in response:
            self.create_time = response['create_time']
        if 'discount_detail_list' in response:
            self.discount_detail_list = response['discount_detail_list']
        if 'gmt_payment_time' in response:
            self.gmt_payment_time = response['gmt_payment_time']
        if 'merchant_discount_amount' in response:
            self.merchant_discount_amount = response['merchant_discount_amount']
        if 'order_no' in response:
            self.order_no = response['order_no']
        if 'order_status' in response:
            self.order_status = response['order_status']
        if 'out_order_no' in response:
            self.out_order_no = response['out_order_no']
        if 'pay_channel' in response:
            self.pay_channel = response['pay_channel']
        if 'platform_discount_amount' in response:
            self.platform_discount_amount = response['platform_discount_amount']
        if 'receipt_amount' in response:
            self.receipt_amount = response['receipt_amount']
        if 'total_amount' in response:
            self.total_amount = response['total_amount']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceSportsVenueQueryModel(object):

    def __init__(self):
        self._out_venue_id = None
        self._venue_id = None

    @property
    def out_venue_id(self):
        return self._out_venue_id

    @out_venue_id.setter
    def out_venue_id(self, value):
        self._out_venue_id = value
    @property
    def venue_id(self):
        return self._venue_id

    @venue_id.setter
    def venue_id(self, value):
        self._venue_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.out_venue_id:
            if hasattr(self.out_venue_id, 'to_alipay_dict'):
                params['out_venue_id'] = self.out_venue_id.to_alipay_dict()
            else:
                params['out_venue_id'] = self.out_venue_id
        if self.venue_id:
            if hasattr(self.venue_id, 'to_alipay_dict'):
                params['venue_id'] = self.venue_id.to_alipay_dict()
            else:
                params['venue_id'] = self.venue_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceSportsVenueQueryModel()
        if 'out_venue_id' in d:
            o.out_venue_id = d['out_venue_id']
        if 'venue_id' in d:
            o.venue_id = d['venue_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TemplateTextMessageDTO import TemplateTextMessageDTO


class TemplateOperationDTO(object):

    def __init__(self):
        self._alt_text = None
        self._format_type = None
        self._message = None
        self._message_encoding = None
        self._text_messages = None

    @property
    def alt_text(self):
        return self._alt_text

    @alt_text.setter
    def alt_text(self, value):
        self._alt_text = value
    @property
    def format_type(self):
        return self._format_type

    @format_type.setter
    def format_type(self, value):
        self._format_type = value
    @property
    def message(self):
        return self._message

    @message.setter
    def message(self, value):
        self._message = value
    @property
    def message_encoding(self):
        return self._message_encoding

    @message_encoding.setter
    def message_encoding(self, value):
        self._message_encoding = value
    @property
    def text_messages(self):
        return self._text_messages

    @text_messages.setter
    def text_messages(self, value):
        if isinstance(value, list):
            self._text_messages = list()
            for i in value:
                if isinstance(i, TemplateTextMessageDTO):
                    self._text_messages.append(i)
                else:
                    self._text_messages.append(TemplateTextMessageDTO.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.alt_text:
            if hasattr(self.alt_text, 'to_alipay_dict'):
                params['alt_text'] = self.alt_text.to_alipay_dict()
            else:
                params['alt_text'] = self.alt_text
        if self.format_type:
            if hasattr(self.format_type, 'to_alipay_dict'):
                params['format_type'] = self.format_type.to_alipay_dict()
            else:
                params['format_type'] = self.format_type
        if self.message:
            if hasattr(self.message, 'to_alipay_dict'):
                params['message'] = self.message.to_alipay_dict()
            else:
                params['message'] = self.message
        if self.message_encoding:
            if hasattr(self.message_encoding, 'to_alipay_dict'):
                params['message_encoding'] = self.message_encoding.to_alipay_dict()
            else:
                params['message_encoding'] = self.message_encoding
        if self.text_messages:
            if isinstance(self.text_messages, list):
                for i in range(0, len(self.text_messages)):
                    element = self.text_messages[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.text_messages[i] = element.to_alipay_dict()
            if hasattr(self.text_messages, 'to_alipay_dict'):
                params['text_messages'] = self.text_messages.to_alipay_dict()
            else:
                params['text_messages'] = self.text_messages
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TemplateOperationDTO()
        if 'alt_text' in d:
            o.alt_text = d['alt_text']
        if 'format_type' in d:
            o.format_type = d['format_type']
        if 'message' in d:
            o.message = d['message']
        if 'message_encoding' in d:
            o.message_encoding = d['message_encoding']
        if 'text_messages' in d:
            o.text_messages = d['text_messages']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayDataDataserviceAdOfflineResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataDataserviceAdOfflineResponse, self).__init__()
        self._success_id_list = None

    @property
    def success_id_list(self):
        return self._success_id_list

    @success_id_list.setter
    def success_id_list(self, value):
        if isinstance(value, list):
            self._success_id_list = list()
            for i in value:
                self._success_id_list.append(i)

    def parse_response_content(self, response_content):
        response = super(AlipayDataDataserviceAdOfflineResponse, self).parse_response_content(response_content)
        if 'success_id_list' in response:
            self.success_id_list = response['success_id_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayInsSceneFamilydoctorItemBatchqueryModel(object):

    def __init__(self):
        self._ant_ser_contract_no = None
        self._disease_name_list = None
        self._emergency = None
        self._general_name_list = None

    @property
    def ant_ser_contract_no(self):
        return self._ant_ser_contract_no

    @ant_ser_contract_no.setter
    def ant_ser_contract_no(self, value):
        self._ant_ser_contract_no = value
    @property
    def disease_name_list(self):
        return self._disease_name_list

    @disease_name_list.setter
    def disease_name_list(self, value):
        if isinstance(value, list):
            self._disease_name_list = list()
            for i in value:
                self._disease_name_list.append(i)
    @property
    def emergency(self):
        return self._emergency

    @emergency.setter
    def emergency(self, value):
        self._emergency = value
    @property
    def general_name_list(self):
        return self._general_name_list

    @general_name_list.setter
    def general_name_list(self, value):
        if isinstance(value, list):
            self._general_name_list = list()
            for i in value:
                self._general_name_list.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.ant_ser_contract_no:
            if hasattr(self.ant_ser_contract_no, 'to_alipay_dict'):
                params['ant_ser_contract_no'] = self.ant_ser_contract_no.to_alipay_dict()
            else:
                params['ant_ser_contract_no'] = self.ant_ser_contract_no
        if self.disease_name_list:
            if isinstance(self.disease_name_list, list):
                for i in range(0, len(self.disease_name_list)):
                    element = self.disease_name_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.disease_name_list[i] = element.to_alipay_dict()
            if hasattr(self.disease_name_list, 'to_alipay_dict'):
                params['disease_name_list'] = self.disease_name_list.to_alipay_dict()
            else:
                params['disease_name_list'] = self.disease_name_list
        if self.emergency:
            if hasattr(self.emergency, 'to_alipay_dict'):
                params['emergency'] = self.emergency.to_alipay_dict()
            else:
                params['emergency'] = self.emergency
        if self.general_name_list:
            if isinstance(self.general_name_list, list):
                for i in range(0, len(self.general_name_list)):
                    element = self.general_name_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.general_name_list[i] = element.to_alipay_dict()
            if hasattr(self.general_name_list, 'to_alipay_dict'):
                params['general_name_list'] = self.general_name_list.to_alipay_dict()
            else:
                params['general_name_list'] = self.general_name_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsSceneFamilydoctorItemBatchqueryModel()
        if 'ant_ser_contract_no' in d:
            o.ant_ser_contract_no = d['ant_ser_contract_no']
        if 'disease_name_list' in d:
            o.disease_name_list = d['disease_name_list']
        if 'emergency' in d:
            o.emergency = d['emergency']
        if 'general_name_list' in d:
            o.general_name_list = d['general_name_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.FillContent import FillContent
from alipay.aop.api.domain.SignField import SignField


class TemplateInfo(object):

    def __init__(self):
        self._fill_contents = None
        self._name = None
        self._signfields = None
        self._template_id = None

    @property
    def fill_contents(self):
        return self._fill_contents

    @fill_contents.setter
    def fill_contents(self, value):
        if isinstance(value, list):
            self._fill_contents = list()
            for i in value:
                if isinstance(i, FillContent):
                    self._fill_contents.append(i)
                else:
                    self._fill_contents.append(FillContent.from_alipay_dict(i))
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def signfields(self):
        return self._signfields

    @signfields.setter
    def signfields(self, value):
        if isinstance(value, SignField):
            self._signfields = value
        else:
            self._signfields = SignField.from_alipay_dict(value)
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.fill_contents:
            if isinstance(self.fill_contents, list):
                for i in range(0, len(self.fill_contents)):
                    element = self.fill_contents[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.fill_contents[i] = element.to_alipay_dict()
            if hasattr(self.fill_contents, 'to_alipay_dict'):
                params['fill_contents'] = self.fill_contents.to_alipay_dict()
            else:
                params['fill_contents'] = self.fill_contents
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.signfields:
            if hasattr(self.signfields, 'to_alipay_dict'):
                params['signfields'] = self.signfields.to_alipay_dict()
            else:
                params['signfields'] = self.signfields
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TemplateInfo()
        if 'fill_contents' in d:
            o.fill_contents = d['fill_contents']
        if 'name' in d:
            o.name = d['name']
        if 'signfields' in d:
            o.signfields = d['signfields']
        if 'template_id' in d:
            o.template_id = d['template_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCreditPeIndustryTradeCloseModel(object):

    def __init__(self):
        self._close_time = None
        self._ext_info = None
        self._operate = None
        self._out_fund_no = None
        self._product_code = None
        self._zm_order_id = None

    @property
    def close_time(self):
        return self._close_time

    @close_time.setter
    def close_time(self, value):
        self._close_time = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def operate(self):
        return self._operate

    @operate.setter
    def operate(self, value):
        self._operate = value
    @property
    def out_fund_no(self):
        return self._out_fund_no

    @out_fund_no.setter
    def out_fund_no(self, value):
        self._out_fund_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def zm_order_id(self):
        return self._zm_order_id

    @zm_order_id.setter
    def zm_order_id(self, value):
        self._zm_order_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.close_time:
            if hasattr(self.close_time, 'to_alipay_dict'):
                params['close_time'] = self.close_time.to_alipay_dict()
            else:
                params['close_time'] = self.close_time
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.operate:
            if hasattr(self.operate, 'to_alipay_dict'):
                params['operate'] = self.operate.to_alipay_dict()
            else:
                params['operate'] = self.operate
        if self.out_fund_no:
            if hasattr(self.out_fund_no, 'to_alipay_dict'):
                params['out_fund_no'] = self.out_fund_no.to_alipay_dict()
            else:
                params['out_fund_no'] = self.out_fund_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.zm_order_id:
            if hasattr(self.zm_order_id, 'to_alipay_dict'):
                params['zm_order_id'] = self.zm_order_id.to_alipay_dict()
            else:
                params['zm_order_id'] = self.zm_order_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditPeIndustryTradeCloseModel()
        if 'close_time' in d:
            o.close_time = d['close_time']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'operate' in d:
            o.operate = d['operate']
        if 'out_fund_no' in d:
            o.out_fund_no = d['out_fund_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'zm_order_id' in d:
            o.zm_order_id = d['zm_order_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceKidsTokenCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceKidsTokenCreateResponse, self).__init__()
        self._expire_time = None
        self._kids_token = None

    @property
    def expire_time(self):
        return self._expire_time

    @expire_time.setter
    def expire_time(self, value):
        self._expire_time = value
    @property
    def kids_token(self):
        return self._kids_token

    @kids_token.setter
    def kids_token(self, value):
        self._kids_token = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceKidsTokenCreateResponse, self).parse_response_content(response_content)
        if 'expire_time' in response:
            self.expire_time = response['expire_time']
        if 'kids_token' in response:
            self.kids_token = response['kids_token']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class FaceSearchUserInfo(object):

    def __init__(self):
        self._customuserid = None
        self._merchantid = None
        self._merchantuid = None
        self._score = None

    @property
    def customuserid(self):
        return self._customuserid

    @customuserid.setter
    def customuserid(self, value):
        self._customuserid = value
    @property
    def merchantid(self):
        return self._merchantid

    @merchantid.setter
    def merchantid(self, value):
        self._merchantid = value
    @property
    def merchantuid(self):
        return self._merchantuid

    @merchantuid.setter
    def merchantuid(self, value):
        self._merchantuid = value
    @property
    def score(self):
        return self._score

    @score.setter
    def score(self, value):
        self._score = value


    def to_alipay_dict(self):
        params = dict()
        if self.customuserid:
            if hasattr(self.customuserid, 'to_alipay_dict'):
                params['customuserid'] = self.customuserid.to_alipay_dict()
            else:
                params['customuserid'] = self.customuserid
        if self.merchantid:
            if hasattr(self.merchantid, 'to_alipay_dict'):
                params['merchantid'] = self.merchantid.to_alipay_dict()
            else:
                params['merchantid'] = self.merchantid
        if self.merchantuid:
            if hasattr(self.merchantuid, 'to_alipay_dict'):
                params['merchantuid'] = self.merchantuid.to_alipay_dict()
            else:
                params['merchantuid'] = self.merchantuid
        if self.score:
            if hasattr(self.score, 'to_alipay_dict'):
                params['score'] = self.score.to_alipay_dict()
            else:
                params['score'] = self.score
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FaceSearchUserInfo()
        if 'customuserid' in d:
            o.customuserid = d['customuserid']
        if 'merchantid' in d:
            o.merchantid = d['merchantid']
        if 'merchantuid' in d:
            o.merchantuid = d['merchantuid']
        if 'score' in d:
            o.score = d['score']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOfflineMarketShopDiscountQueryModel(object):

    def __init__(self):
        self._camp_biz_type_list = None
        self._query_type = None
        self._shop_id = None
        self._user_id = None

    @property
    def camp_biz_type_list(self):
        return self._camp_biz_type_list

    @camp_biz_type_list.setter
    def camp_biz_type_list(self, value):
        if isinstance(value, list):
            self._camp_biz_type_list = list()
            for i in value:
                self._camp_biz_type_list.append(i)
    @property
    def query_type(self):
        return self._query_type

    @query_type.setter
    def query_type(self, value):
        self._query_type = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.camp_biz_type_list:
            if isinstance(self.camp_biz_type_list, list):
                for i in range(0, len(self.camp_biz_type_list)):
                    element = self.camp_biz_type_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.camp_biz_type_list[i] = element.to_alipay_dict()
            if hasattr(self.camp_biz_type_list, 'to_alipay_dict'):
                params['camp_biz_type_list'] = self.camp_biz_type_list.to_alipay_dict()
            else:
                params['camp_biz_type_list'] = self.camp_biz_type_list
        if self.query_type:
            if hasattr(self.query_type, 'to_alipay_dict'):
                params['query_type'] = self.query_type.to_alipay_dict()
            else:
                params['query_type'] = self.query_type
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOfflineMarketShopDiscountQueryModel()
        if 'camp_biz_type_list' in d:
            o.camp_biz_type_list = d['camp_biz_type_list']
        if 'query_type' in d:
            o.query_type = d['query_type']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PaidOuterCardPriceDetailDTO import PaidOuterCardPriceDetailDTO


class PaidOuterCardSellingConfDTO(object):

    def __init__(self):
        self._end_date = None
        self._price_detail = None
        self._selling_url = None
        self._start_date = None

    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def price_detail(self):
        return self._price_detail

    @price_detail.setter
    def price_detail(self, value):
        if isinstance(value, list):
            self._price_detail = list()
            for i in value:
                if isinstance(i, PaidOuterCardPriceDetailDTO):
                    self._price_detail.append(i)
                else:
                    self._price_detail.append(PaidOuterCardPriceDetailDTO.from_alipay_dict(i))
    @property
    def selling_url(self):
        return self._selling_url

    @selling_url.setter
    def selling_url(self, value):
        self._selling_url = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.price_detail:
            if isinstance(self.price_detail, list):
                for i in range(0, len(self.price_detail)):
                    element = self.price_detail[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.price_detail[i] = element.to_alipay_dict()
            if hasattr(self.price_detail, 'to_alipay_dict'):
                params['price_detail'] = self.price_detail.to_alipay_dict()
            else:
                params['price_detail'] = self.price_detail
        if self.selling_url:
            if hasattr(self.selling_url, 'to_alipay_dict'):
                params['selling_url'] = self.selling_url.to_alipay_dict()
            else:
                params['selling_url'] = self.selling_url
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PaidOuterCardSellingConfDTO()
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'price_detail' in d:
            o.price_detail = d['price_detail']
        if 'selling_url' in d:
            o.selling_url = d['selling_url']
        if 'start_date' in d:
            o.start_date = d['start_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySocialQuestionnareGrayUpgradeResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySocialQuestionnareGrayUpgradeResponse, self).__init__()
        self._ext_info = None
        self._gray_percent = None
        self._qstn_id = None

    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def gray_percent(self):
        return self._gray_percent

    @gray_percent.setter
    def gray_percent(self, value):
        self._gray_percent = value
    @property
    def qstn_id(self):
        return self._qstn_id

    @qstn_id.setter
    def qstn_id(self, value):
        self._qstn_id = value

    def parse_response_content(self, response_content):
        response = super(AlipaySocialQuestionnareGrayUpgradeResponse, self).parse_response_content(response_content)
        if 'ext_info' in response:
            self.ext_info = response['ext_info']
        if 'gray_percent' in response:
            self.gray_percent = response['gray_percent']
        if 'qstn_id' in response:
            self.qstn_id = response['qstn_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundTransIcrowdTagModifyModel(object):

    def __init__(self):
        self._mobile = None
        self._scene_code = None
        self._tag_code = None
        self._tag_value = None
        self._user_id = None

    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def tag_code(self):
        return self._tag_code

    @tag_code.setter
    def tag_code(self, value):
        self._tag_code = value
    @property
    def tag_value(self):
        return self._tag_value

    @tag_value.setter
    def tag_value(self, value):
        self._tag_value = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.tag_code:
            if hasattr(self.tag_code, 'to_alipay_dict'):
                params['tag_code'] = self.tag_code.to_alipay_dict()
            else:
                params['tag_code'] = self.tag_code
        if self.tag_value:
            if hasattr(self.tag_value, 'to_alipay_dict'):
                params['tag_value'] = self.tag_value.to_alipay_dict()
            else:
                params['tag_value'] = self.tag_value
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundTransIcrowdTagModifyModel()
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'tag_code' in d:
            o.tag_code = d['tag_code']
        if 'tag_value' in d:
            o.tag_value = d['tag_value']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniTipsDeliveryQueryModel(object):

    def __init__(self):
        self._delivery_id = None

    @property
    def delivery_id(self):
        return self._delivery_id

    @delivery_id.setter
    def delivery_id(self, value):
        self._delivery_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.delivery_id:
            if hasattr(self.delivery_id, 'to_alipay_dict'):
                params['delivery_id'] = self.delivery_id.to_alipay_dict()
            else:
                params['delivery_id'] = self.delivery_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniTipsDeliveryQueryModel()
        if 'delivery_id' in d:
            o.delivery_id = d['delivery_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCreditEpProductCodeApplyModel(object):

    def __init__(self):
        self._apply_desc = None
        self._code_num = None
        self._org_biz_no = None
        self._product_list = None

    @property
    def apply_desc(self):
        return self._apply_desc

    @apply_desc.setter
    def apply_desc(self, value):
        self._apply_desc = value
    @property
    def code_num(self):
        return self._code_num

    @code_num.setter
    def code_num(self, value):
        self._code_num = value
    @property
    def org_biz_no(self):
        return self._org_biz_no

    @org_biz_no.setter
    def org_biz_no(self, value):
        self._org_biz_no = value
    @property
    def product_list(self):
        return self._product_list

    @product_list.setter
    def product_list(self, value):
        self._product_list = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_desc:
            if hasattr(self.apply_desc, 'to_alipay_dict'):
                params['apply_desc'] = self.apply_desc.to_alipay_dict()
            else:
                params['apply_desc'] = self.apply_desc
        if self.code_num:
            if hasattr(self.code_num, 'to_alipay_dict'):
                params['code_num'] = self.code_num.to_alipay_dict()
            else:
                params['code_num'] = self.code_num
        if self.org_biz_no:
            if hasattr(self.org_biz_no, 'to_alipay_dict'):
                params['org_biz_no'] = self.org_biz_no.to_alipay_dict()
            else:
                params['org_biz_no'] = self.org_biz_no
        if self.product_list:
            if hasattr(self.product_list, 'to_alipay_dict'):
                params['product_list'] = self.product_list.to_alipay_dict()
            else:
                params['product_list'] = self.product_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditEpProductCodeApplyModel()
        if 'apply_desc' in d:
            o.apply_desc = d['apply_desc']
        if 'code_num' in d:
            o.code_num = d['code_num']
        if 'org_biz_no' in d:
            o.org_biz_no = d['org_biz_no']
        if 'product_list' in d:
            o.product_list = d['product_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossProdGfsettleprodApplyQueryModel(object):

    def __init__(self):
        self._arrangement_no = None
        self._ip_role_id = None
        self._type = None

    @property
    def arrangement_no(self):
        return self._arrangement_no

    @arrangement_no.setter
    def arrangement_no(self, value):
        self._arrangement_no = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.arrangement_no:
            if hasattr(self.arrangement_no, 'to_alipay_dict'):
                params['arrangement_no'] = self.arrangement_no.to_alipay_dict()
            else:
                params['arrangement_no'] = self.arrangement_no
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossProdGfsettleprodApplyQueryModel()
        if 'arrangement_no' in d:
            o.arrangement_no = d['arrangement_no']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PersonnalBankAccountInfo(object):

    def __init__(self):
        self._personal_bank_account_mobile = None
        self._personal_bank_card_no = None
        self._personal_bank_holder_certno = None
        self._personal_bank_holder_name = None

    @property
    def personal_bank_account_mobile(self):
        return self._personal_bank_account_mobile

    @personal_bank_account_mobile.setter
    def personal_bank_account_mobile(self, value):
        self._personal_bank_account_mobile = value
    @property
    def personal_bank_card_no(self):
        return self._personal_bank_card_no

    @personal_bank_card_no.setter
    def personal_bank_card_no(self, value):
        self._personal_bank_card_no = value
    @property
    def personal_bank_holder_certno(self):
        return self._personal_bank_holder_certno

    @personal_bank_holder_certno.setter
    def personal_bank_holder_certno(self, value):
        self._personal_bank_holder_certno = value
    @property
    def personal_bank_holder_name(self):
        return self._personal_bank_holder_name

    @personal_bank_holder_name.setter
    def personal_bank_holder_name(self, value):
        self._personal_bank_holder_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.personal_bank_account_mobile:
            if hasattr(self.personal_bank_account_mobile, 'to_alipay_dict'):
                params['personal_bank_account_mobile'] = self.personal_bank_account_mobile.to_alipay_dict()
            else:
                params['personal_bank_account_mobile'] = self.personal_bank_account_mobile
        if self.personal_bank_card_no:
            if hasattr(self.personal_bank_card_no, 'to_alipay_dict'):
                params['personal_bank_card_no'] = self.personal_bank_card_no.to_alipay_dict()
            else:
                params['personal_bank_card_no'] = self.personal_bank_card_no
        if self.personal_bank_holder_certno:
            if hasattr(self.personal_bank_holder_certno, 'to_alipay_dict'):
                params['personal_bank_holder_certno'] = self.personal_bank_holder_certno.to_alipay_dict()
            else:
                params['personal_bank_holder_certno'] = self.personal_bank_holder_certno
        if self.personal_bank_holder_name:
            if hasattr(self.personal_bank_holder_name, 'to_alipay_dict'):
                params['personal_bank_holder_name'] = self.personal_bank_holder_name.to_alipay_dict()
            else:
                params['personal_bank_holder_name'] = self.personal_bank_holder_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PersonnalBankAccountInfo()
        if 'personal_bank_account_mobile' in d:
            o.personal_bank_account_mobile = d['personal_bank_account_mobile']
        if 'personal_bank_card_no' in d:
            o.personal_bank_card_no = d['personal_bank_card_no']
        if 'personal_bank_holder_certno' in d:
            o.personal_bank_holder_certno = d['personal_bank_holder_certno']
        if 'personal_bank_holder_name' in d:
            o.personal_bank_holder_name = d['personal_bank_holder_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SearchBaseItems(object):

    def __init__(self):
        self._can_search = None
        self._key_words = None

    @property
    def can_search(self):
        return self._can_search

    @can_search.setter
    def can_search(self, value):
        self._can_search = value
    @property
    def key_words(self):
        return self._key_words

    @key_words.setter
    def key_words(self, value):
        if isinstance(value, list):
            self._key_words = list()
            for i in value:
                self._key_words.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.can_search:
            if hasattr(self.can_search, 'to_alipay_dict'):
                params['can_search'] = self.can_search.to_alipay_dict()
            else:
                params['can_search'] = self.can_search
        if self.key_words:
            if isinstance(self.key_words, list):
                for i in range(0, len(self.key_words)):
                    element = self.key_words[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.key_words[i] = element.to_alipay_dict()
            if hasattr(self.key_words, 'to_alipay_dict'):
                params['key_words'] = self.key_words.to_alipay_dict()
            else:
                params['key_words'] = self.key_words
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SearchBaseItems()
        if 'can_search' in d:
            o.can_search = d['can_search']
        if 'key_words' in d:
            o.key_words = d['key_words']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayTradeRepaybillBillinConfirmResponse(AlipayResponse):

    def __init__(self):
        super(AlipayTradeRepaybillBillinConfirmResponse, self).__init__()
        self._bill_amount = None
        self._bill_no = None
        self._bill_status = None

    @property
    def bill_amount(self):
        return self._bill_amount

    @bill_amount.setter
    def bill_amount(self, value):
        self._bill_amount = value
    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def bill_status(self):
        return self._bill_status

    @bill_status.setter
    def bill_status(self, value):
        self._bill_status = value

    def parse_response_content(self, response_content):
        response = super(AlipayTradeRepaybillBillinConfirmResponse, self).parse_response_content(response_content)
        if 'bill_amount' in response:
            self.bill_amount = response['bill_amount']
        if 'bill_no' in response:
            self.bill_no = response['bill_no']
        if 'bill_status' in response:
            self.bill_status = response['bill_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ModelColumn import ModelColumn


class AlipayMarketingDataModelQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingDataModelQueryResponse, self).__init__()
        self._model_column = None

    @property
    def model_column(self):
        return self._model_column

    @model_column.setter
    def model_column(self, value):
        if isinstance(value, list):
            self._model_column = list()
            for i in value:
                if isinstance(i, ModelColumn):
                    self._model_column.append(i)
                else:
                    self._model_column.append(ModelColumn.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingDataModelQueryResponse, self).parse_response_content(response_content)
        if 'model_column' in response:
            self.model_column = response['model_column']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CityShopModel import CityShopModel


class KoubeiMerchantOperatorShopQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMerchantOperatorShopQueryResponse, self).__init__()
        self._city_shop_models = None

    @property
    def city_shop_models(self):
        return self._city_shop_models

    @city_shop_models.setter
    def city_shop_models(self, value):
        if isinstance(value, list):
            self._city_shop_models = list()
            for i in value:
                if isinstance(i, CityShopModel):
                    self._city_shop_models.append(i)
                else:
                    self._city_shop_models.append(CityShopModel.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(KoubeiMerchantOperatorShopQueryResponse, self).parse_response_content(response_content)
        if 'city_shop_models' in response:
            self.city_shop_models = response['city_shop_models']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaMerchantContractOnofferQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaMerchantContractOnofferQueryResponse, self).__init__()
        self._cancel_operator = None
        self._cancel_supported = None
        self._contract_content = None
        self._contract_no = None
        self._contract_principal_desc = None
        self._contract_principal_logo = None
        self._contract_status = None
        self._ext_info = None
        self._fufilment_callback_url = None
        self._fufilment_cnt = None
        self._fufilment_desc = None
        self._fufilment_end_time = None
        self._fufilment_period_type = None
        self._fufilment_start_time = None
        self._gmt_accept = None
        self._gmt_cancel = None
        self._gmt_due = None
        self._gmt_end = None
        self._item_end_time = None
        self._item_no = None
        self._item_start_time = None
        self._offer_creater_id = None
        self._offer_creater_name = None
        self._offer_creater_type = None
        self._out_biz_no = None
        self._out_content_no = None
        self._sign_principal_id = None
        self._sign_principal_type = None
        self._subjects = None

    @property
    def cancel_operator(self):
        return self._cancel_operator

    @cancel_operator.setter
    def cancel_operator(self, value):
        self._cancel_operator = value
    @property
    def cancel_supported(self):
        return self._cancel_supported

    @cancel_supported.setter
    def cancel_supported(self, value):
        self._cancel_supported = value
    @property
    def contract_content(self):
        return self._contract_content

    @contract_content.setter
    def contract_content(self, value):
        self._contract_content = value
    @property
    def contract_no(self):
        return self._contract_no

    @contract_no.setter
    def contract_no(self, value):
        self._contract_no = value
    @property
    def contract_principal_desc(self):
        return self._contract_principal_desc

    @contract_principal_desc.setter
    def contract_principal_desc(self, value):
        self._contract_principal_desc = value
    @property
    def contract_principal_logo(self):
        return self._contract_principal_logo

    @contract_principal_logo.setter
    def contract_principal_logo(self, value):
        self._contract_principal_logo = value
    @property
    def contract_status(self):
        return self._contract_status

    @contract_status.setter
    def contract_status(self, value):
        self._contract_status = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def fufilment_callback_url(self):
        return self._fufilment_callback_url

    @fufilment_callback_url.setter
    def fufilment_callback_url(self, value):
        self._fufilment_callback_url = value
    @property
    def fufilment_cnt(self):
        return self._fufilment_cnt

    @fufilment_cnt.setter
    def fufilment_cnt(self, value):
        self._fufilment_cnt = value
    @property
    def fufilment_desc(self):
        return self._fufilment_desc

    @fufilment_desc.setter
    def fufilment_desc(self, value):
        self._fufilment_desc = value
    @property
    def fufilment_end_time(self):
        return self._fufilment_end_time

    @fufilment_end_time.setter
    def fufilment_end_time(self, value):
        self._fufilment_end_time = value
    @property
    def fufilment_period_type(self):
        return self._fufilment_period_type

    @fufilment_period_type.setter
    def fufilment_period_type(self, value):
        self._fufilment_period_type = value
    @property
    def fufilment_start_time(self):
        return self._fufilment_start_time

    @fufilment_start_time.setter
    def fufilment_start_time(self, value):
        self._fufilment_start_time = value
    @property
    def gmt_accept(self):
        return self._gmt_accept

    @gmt_accept.setter
    def gmt_accept(self, value):
        self._gmt_accept = value
    @property
    def gmt_cancel(self):
        return self._gmt_cancel

    @gmt_cancel.setter
    def gmt_cancel(self, value):
        self._gmt_cancel = value
    @property
    def gmt_due(self):
        return self._gmt_due

    @gmt_due.setter
    def gmt_due(self, value):
        self._gmt_due = value
    @property
    def gmt_end(self):
        return self._gmt_end

    @gmt_end.setter
    def gmt_end(self, value):
        self._gmt_end = value
    @property
    def item_end_time(self):
        return self._item_end_time

    @item_end_time.setter
    def item_end_time(self, value):
        self._item_end_time = value
    @property
    def item_no(self):
        return self._item_no

    @item_no.setter
    def item_no(self, value):
        self._item_no = value
    @property
    def item_start_time(self):
        return self._item_start_time

    @item_start_time.setter
    def item_start_time(self, value):
        self._item_start_time = value
    @property
    def offer_creater_id(self):
        return self._offer_creater_id

    @offer_creater_id.setter
    def offer_creater_id(self, value):
        self._offer_creater_id = value
    @property
    def offer_creater_name(self):
        return self._offer_creater_name

    @offer_creater_name.setter
    def offer_creater_name(self, value):
        self._offer_creater_name = value
    @property
    def offer_creater_type(self):
        return self._offer_creater_type

    @offer_creater_type.setter
    def offer_creater_type(self, value):
        self._offer_creater_type = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def out_content_no(self):
        return self._out_content_no

    @out_content_no.setter
    def out_content_no(self, value):
        self._out_content_no = value
    @property
    def sign_principal_id(self):
        return self._sign_principal_id

    @sign_principal_id.setter
    def sign_principal_id(self, value):
        self._sign_principal_id = value
    @property
    def sign_principal_type(self):
        return self._sign_principal_type

    @sign_principal_type.setter
    def sign_principal_type(self, value):
        self._sign_principal_type = value
    @property
    def subjects(self):
        return self._subjects

    @subjects.setter
    def subjects(self, value):
        self._subjects = value

    def parse_response_content(self, response_content):
        response = super(ZhimaMerchantContractOnofferQueryResponse, self).parse_response_content(response_content)
        if 'cancel_operator' in response:
            self.cancel_operator = response['cancel_operator']
        if 'cancel_supported' in response:
            self.cancel_supported = response['cancel_supported']
        if 'contract_content' in response:
            self.contract_content = response['contract_content']
        if 'contract_no' in response:
            self.contract_no = response['contract_no']
        if 'contract_principal_desc' in response:
            self.contract_principal_desc = response['contract_principal_desc']
        if 'contract_principal_logo' in response:
            self.contract_principal_logo = response['contract_principal_logo']
        if 'contract_status' in response:
            self.contract_status = response['contract_status']
        if 'ext_info' in response:
            self.ext_info = response['ext_info']
        if 'fufilment_callback_url' in response:
            self.fufilment_callback_url = response['fufilment_callback_url']
        if 'fufilment_cnt' in response:
            self.fufilment_cnt = response['fufilment_cnt']
        if 'fufilment_desc' in response:
            self.fufilment_desc = response['fufilment_desc']
        if 'fufilment_end_time' in response:
            self.fufilment_end_time = response['fufilment_end_time']
        if 'fufilment_period_type' in response:
            self.fufilment_period_type = response['fufilment_period_type']
        if 'fufilment_start_time' in response:
            self.fufilment_start_time = response['fufilment_start_time']
        if 'gmt_accept' in response:
            self.gmt_accept = response['gmt_accept']
        if 'gmt_cancel' in response:
            self.gmt_cancel = response['gmt_cancel']
        if 'gmt_due' in response:
            self.gmt_due = response['gmt_due']
        if 'gmt_end' in response:
            self.gmt_end = response['gmt_end']
        if 'item_end_time' in response:
            self.item_end_time = response['item_end_time']
        if 'item_no' in response:
            self.item_no = response['item_no']
        if 'item_start_time' in response:
            self.item_start_time = response['item_start_time']
        if 'offer_creater_id' in response:
            self.offer_creater_id = response['offer_creater_id']
        if 'offer_creater_name' in response:
            self.offer_creater_name = response['offer_creater_name']
        if 'offer_creater_type' in response:
            self.offer_creater_type = response['offer_creater_type']
        if 'out_biz_no' in response:
            self.out_biz_no = response['out_biz_no']
        if 'out_content_no' in response:
            self.out_content_no = response['out_content_no']
        if 'sign_principal_id' in response:
            self.sign_principal_id = response['sign_principal_id']
        if 'sign_principal_type' in response:
            self.sign_principal_type = response['sign_principal_type']
        if 'subjects' in response:
            self.subjects = response['subjects']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AntMerchantExpandWarehouseOrderSyncModel(object):

    def __init__(self):
        self._assign_item_id = None
        self._new_warehouse_id = None
        self._type = None

    @property
    def assign_item_id(self):
        return self._assign_item_id

    @assign_item_id.setter
    def assign_item_id(self, value):
        self._assign_item_id = value
    @property
    def new_warehouse_id(self):
        return self._new_warehouse_id

    @new_warehouse_id.setter
    def new_warehouse_id(self, value):
        self._new_warehouse_id = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.assign_item_id:
            if hasattr(self.assign_item_id, 'to_alipay_dict'):
                params['assign_item_id'] = self.assign_item_id.to_alipay_dict()
            else:
                params['assign_item_id'] = self.assign_item_id
        if self.new_warehouse_id:
            if hasattr(self.new_warehouse_id, 'to_alipay_dict'):
                params['new_warehouse_id'] = self.new_warehouse_id.to_alipay_dict()
            else:
                params['new_warehouse_id'] = self.new_warehouse_id
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandWarehouseOrderSyncModel()
        if 'assign_item_id' in d:
            o.assign_item_id = d['assign_item_id']
        if 'new_warehouse_id' in d:
            o.new_warehouse_id = d['new_warehouse_id']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OfflinepayErrorIndicator(object):

    def __init__(self):
        self._action_button = None
        self._action_url = None
        self._alipay_inside_tips = None
        self._clean_card = None
        self._default_button = None
        self._default_url = None
        self._desc = None
        self._error_code = None
        self._tips = None
        self._type = None

    @property
    def action_button(self):
        return self._action_button

    @action_button.setter
    def action_button(self, value):
        self._action_button = value
    @property
    def action_url(self):
        return self._action_url

    @action_url.setter
    def action_url(self, value):
        self._action_url = value
    @property
    def alipay_inside_tips(self):
        return self._alipay_inside_tips

    @alipay_inside_tips.setter
    def alipay_inside_tips(self, value):
        self._alipay_inside_tips = value
    @property
    def clean_card(self):
        return self._clean_card

    @clean_card.setter
    def clean_card(self, value):
        self._clean_card = value
    @property
    def default_button(self):
        return self._default_button

    @default_button.setter
    def default_button(self, value):
        self._default_button = value
    @property
    def default_url(self):
        return self._default_url

    @default_url.setter
    def default_url(self, value):
        self._default_url = value
    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def tips(self):
        return self._tips

    @tips.setter
    def tips(self, value):
        self._tips = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_button:
            if hasattr(self.action_button, 'to_alipay_dict'):
                params['action_button'] = self.action_button.to_alipay_dict()
            else:
                params['action_button'] = self.action_button
        if self.action_url:
            if hasattr(self.action_url, 'to_alipay_dict'):
                params['action_url'] = self.action_url.to_alipay_dict()
            else:
                params['action_url'] = self.action_url
        if self.alipay_inside_tips:
            if hasattr(self.alipay_inside_tips, 'to_alipay_dict'):
                params['alipay_inside_tips'] = self.alipay_inside_tips.to_alipay_dict()
            else:
                params['alipay_inside_tips'] = self.alipay_inside_tips
        if self.clean_card:
            if hasattr(self.clean_card, 'to_alipay_dict'):
                params['clean_card'] = self.clean_card.to_alipay_dict()
            else:
                params['clean_card'] = self.clean_card
        if self.default_button:
            if hasattr(self.default_button, 'to_alipay_dict'):
                params['default_button'] = self.default_button.to_alipay_dict()
            else:
                params['default_button'] = self.default_button
        if self.default_url:
            if hasattr(self.default_url, 'to_alipay_dict'):
                params['default_url'] = self.default_url.to_alipay_dict()
            else:
                params['default_url'] = self.default_url
        if self.desc:
            if hasattr(self.desc, 'to_alipay_dict'):
                params['desc'] = self.desc.to_alipay_dict()
            else:
                params['desc'] = self.desc
        if self.error_code:
            if hasattr(self.error_code, 'to_alipay_dict'):
                params['error_code'] = self.error_code.to_alipay_dict()
            else:
                params['error_code'] = self.error_code
        if self.tips:
            if hasattr(self.tips, 'to_alipay_dict'):
                params['tips'] = self.tips.to_alipay_dict()
            else:
                params['tips'] = self.tips
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OfflinepayErrorIndicator()
        if 'action_button' in d:
            o.action_button = d['action_button']
        if 'action_url' in d:
            o.action_url = d['action_url']
        if 'alipay_inside_tips' in d:
            o.alipay_inside_tips = d['alipay_inside_tips']
        if 'clean_card' in d:
            o.clean_card = d['clean_card']
        if 'default_button' in d:
            o.default_button = d['default_button']
        if 'default_url' in d:
            o.default_url = d['default_url']
        if 'desc' in d:
            o.desc = d['desc']
        if 'error_code' in d:
            o.error_code = d['error_code']
        if 'tips' in d:
            o.tips = d['tips']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AlipayYebLqdDataResult import AlipayYebLqdDataResult


class AlipayDataDataserviceYuebaolqdDetailQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataDataserviceYuebaolqdDetailQueryResponse, self).__init__()
        self._yeb_ldq_data = None

    @property
    def yeb_ldq_data(self):
        return self._yeb_ldq_data

    @yeb_ldq_data.setter
    def yeb_ldq_data(self, value):
        if isinstance(value, list):
            self._yeb_ldq_data = list()
            for i in value:
                if isinstance(i, AlipayYebLqdDataResult):
                    self._yeb_ldq_data.append(i)
                else:
                    self._yeb_ldq_data.append(AlipayYebLqdDataResult.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayDataDataserviceYuebaolqdDetailQueryResponse, self).parse_response_content(response_content)
        if 'yeb_ldq_data' in response:
            self.yeb_ldq_data = response['yeb_ldq_data']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceTransportAdStocktaskresultQueryModel(object):

    def __init__(self):
        self._ad_user_id = None
        self._task_id = None

    @property
    def ad_user_id(self):
        return self._ad_user_id

    @ad_user_id.setter
    def ad_user_id(self, value):
        self._ad_user_id = value
    @property
    def task_id(self):
        return self._task_id

    @task_id.setter
    def task_id(self, value):
        self._task_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.ad_user_id:
            if hasattr(self.ad_user_id, 'to_alipay_dict'):
                params['ad_user_id'] = self.ad_user_id.to_alipay_dict()
            else:
                params['ad_user_id'] = self.ad_user_id
        if self.task_id:
            if hasattr(self.task_id, 'to_alipay_dict'):
                params['task_id'] = self.task_id.to_alipay_dict()
            else:
                params['task_id'] = self.task_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportAdStocktaskresultQueryModel()
        if 'ad_user_id' in d:
            o.ad_user_id = d['ad_user_id']
        if 'task_id' in d:
            o.task_id = d['task_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AssetResult import AssetResult


class AntMerchantExpandExpressChangeSyncResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantExpandExpressChangeSyncResponse, self).__init__()
        self._upload_result = None

    @property
    def upload_result(self):
        return self._upload_result

    @upload_result.setter
    def upload_result(self, value):
        if isinstance(value, AssetResult):
            self._upload_result = value
        else:
            self._upload_result = AssetResult.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AntMerchantExpandExpressChangeSyncResponse, self).parse_response_content(response_content)
        if 'upload_result' in response:
            self.upload_result = response['upload_result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AssetResult import AssetResult


class AntMerchantExpandAssetdeliveryAssignSyncResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantExpandAssetdeliveryAssignSyncResponse, self).__init__()
        self._delivery_results = None

    @property
    def delivery_results(self):
        return self._delivery_results

    @delivery_results.setter
    def delivery_results(self, value):
        if isinstance(value, list):
            self._delivery_results = list()
            for i in value:
                if isinstance(i, AssetResult):
                    self._delivery_results.append(i)
                else:
                    self._delivery_results.append(AssetResult.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AntMerchantExpandAssetdeliveryAssignSyncResponse, self).parse_response_content(response_content)
        if 'delivery_results' in response:
            self.delivery_results = response['delivery_results']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ShopPosSchedule import ShopPosSchedule


class KoubeiCateringPosShiftQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiCateringPosShiftQueryResponse, self).__init__()
        self._shop_pos_schedules = None

    @property
    def shop_pos_schedules(self):
        return self._shop_pos_schedules

    @shop_pos_schedules.setter
    def shop_pos_schedules(self, value):
        if isinstance(value, list):
            self._shop_pos_schedules = list()
            for i in value:
                if isinstance(i, ShopPosSchedule):
                    self._shop_pos_schedules.append(i)
                else:
                    self._shop_pos_schedules.append(ShopPosSchedule.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(KoubeiCateringPosShiftQueryResponse, self).parse_response_content(response_content)
        if 'shop_pos_schedules' in response:
            self.shop_pos_schedules = response['shop_pos_schedules']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniUserportraitQueryModel(object):

    def __init__(self):
        self._date_scope = None
        self._portrait_type = None
        self._user_type = None

    @property
    def date_scope(self):
        return self._date_scope

    @date_scope.setter
    def date_scope(self, value):
        self._date_scope = value
    @property
    def portrait_type(self):
        return self._portrait_type

    @portrait_type.setter
    def portrait_type(self, value):
        self._portrait_type = value
    @property
    def user_type(self):
        return self._user_type

    @user_type.setter
    def user_type(self, value):
        self._user_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.date_scope:
            if hasattr(self.date_scope, 'to_alipay_dict'):
                params['date_scope'] = self.date_scope.to_alipay_dict()
            else:
                params['date_scope'] = self.date_scope
        if self.portrait_type:
            if hasattr(self.portrait_type, 'to_alipay_dict'):
                params['portrait_type'] = self.portrait_type.to_alipay_dict()
            else:
                params['portrait_type'] = self.portrait_type
        if self.user_type:
            if hasattr(self.user_type, 'to_alipay_dict'):
                params['user_type'] = self.user_type.to_alipay_dict()
            else:
                params['user_type'] = self.user_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniUserportraitQueryModel()
        if 'date_scope' in d:
            o.date_scope = d['date_scope']
        if 'portrait_type' in d:
            o.portrait_type = d['portrait_type']
        if 'user_type' in d:
            o.user_type = d['user_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaDataFeedbackurlQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaDataFeedbackurlQueryResponse, self).__init__()
        self._feedback_url = None

    @property
    def feedback_url(self):
        return self._feedback_url

    @feedback_url.setter
    def feedback_url(self, value):
        self._feedback_url = value

    def parse_response_content(self, response_content):
        response = super(ZhimaDataFeedbackurlQueryResponse, self).parse_response_content(response_content)
        if 'feedback_url' in response:
            self.feedback_url = response['feedback_url']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.DriverTradeInfo import DriverTradeInfo


class AlipayCommerceTransportTaxiDriverqrcodetradeQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceTransportTaxiDriverqrcodetradeQueryResponse, self).__init__()
        self._driver_qrcode_trade_info_list = None

    @property
    def driver_qrcode_trade_info_list(self):
        return self._driver_qrcode_trade_info_list

    @driver_qrcode_trade_info_list.setter
    def driver_qrcode_trade_info_list(self, value):
        if isinstance(value, list):
            self._driver_qrcode_trade_info_list = list()
            for i in value:
                if isinstance(i, DriverTradeInfo):
                    self._driver_qrcode_trade_info_list.append(i)
                else:
                    self._driver_qrcode_trade_info_list.append(DriverTradeInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceTransportTaxiDriverqrcodetradeQueryResponse, self).parse_response_content(response_content)
        if 'driver_qrcode_trade_info_list' in response:
            self.driver_qrcode_trade_info_list = response['driver_qrcode_trade_info_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankCreditLoanapplyQrcodeInvalidDeleteResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditLoanapplyQrcodeInvalidDeleteResponse, self).__init__()
        self._status = None

    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditLoanapplyQrcodeInvalidDeleteResponse, self).parse_response_content(response_content)
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFinanceFundFundprodQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFinanceFundFundprodQueryResponse, self).__init__()
        self._establishment_date = None
        self._fund_code = None
        self._fund_name = None
        self._fund_name_abbr = None
        self._net_value = None
        self._net_value_date = None
        self._profit_seven_days = None
        self._profit_ten_thousand = None
        self._risk_evaluation = None

    @property
    def establishment_date(self):
        return self._establishment_date

    @establishment_date.setter
    def establishment_date(self, value):
        self._establishment_date = value
    @property
    def fund_code(self):
        return self._fund_code

    @fund_code.setter
    def fund_code(self, value):
        self._fund_code = value
    @property
    def fund_name(self):
        return self._fund_name

    @fund_name.setter
    def fund_name(self, value):
        self._fund_name = value
    @property
    def fund_name_abbr(self):
        return self._fund_name_abbr

    @fund_name_abbr.setter
    def fund_name_abbr(self, value):
        self._fund_name_abbr = value
    @property
    def net_value(self):
        return self._net_value

    @net_value.setter
    def net_value(self, value):
        self._net_value = value
    @property
    def net_value_date(self):
        return self._net_value_date

    @net_value_date.setter
    def net_value_date(self, value):
        self._net_value_date = value
    @property
    def profit_seven_days(self):
        return self._profit_seven_days

    @profit_seven_days.setter
    def profit_seven_days(self, value):
        self._profit_seven_days = value
    @property
    def profit_ten_thousand(self):
        return self._profit_ten_thousand

    @profit_ten_thousand.setter
    def profit_ten_thousand(self, value):
        self._profit_ten_thousand = value
    @property
    def risk_evaluation(self):
        return self._risk_evaluation

    @risk_evaluation.setter
    def risk_evaluation(self, value):
        self._risk_evaluation = value

    def parse_response_content(self, response_content):
        response = super(AlipayFinanceFundFundprodQueryResponse, self).parse_response_content(response_content)
        if 'establishment_date' in response:
            self.establishment_date = response['establishment_date']
        if 'fund_code' in response:
            self.fund_code = response['fund_code']
        if 'fund_name' in response:
            self.fund_name = response['fund_name']
        if 'fund_name_abbr' in response:
            self.fund_name_abbr = response['fund_name_abbr']
        if 'net_value' in response:
            self.net_value = response['net_value']
        if 'net_value_date' in response:
            self.net_value_date = response['net_value_date']
        if 'profit_seven_days' in response:
            self.profit_seven_days = response['profit_seven_days']
        if 'profit_ten_thousand' in response:
            self.profit_ten_thousand = response['profit_ten_thousand']
        if 'risk_evaluation' in response:
            self.risk_evaluation = response['risk_evaluation']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ShellCompanyGsChangeDetail(object):

    def __init__(self):
        self._after_content = None
        self._before_content = None
        self._change_type = None
        self._description = None
        self._title = None
        self._update_time = None

    @property
    def after_content(self):
        return self._after_content

    @after_content.setter
    def after_content(self, value):
        self._after_content = value
    @property
    def before_content(self):
        return self._before_content

    @before_content.setter
    def before_content(self, value):
        self._before_content = value
    @property
    def change_type(self):
        return self._change_type

    @change_type.setter
    def change_type(self, value):
        self._change_type = value
    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def update_time(self):
        return self._update_time

    @update_time.setter
    def update_time(self, value):
        self._update_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.after_content:
            if hasattr(self.after_content, 'to_alipay_dict'):
                params['after_content'] = self.after_content.to_alipay_dict()
            else:
                params['after_content'] = self.after_content
        if self.before_content:
            if hasattr(self.before_content, 'to_alipay_dict'):
                params['before_content'] = self.before_content.to_alipay_dict()
            else:
                params['before_content'] = self.before_content
        if self.change_type:
            if hasattr(self.change_type, 'to_alipay_dict'):
                params['change_type'] = self.change_type.to_alipay_dict()
            else:
                params['change_type'] = self.change_type
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.update_time:
            if hasattr(self.update_time, 'to_alipay_dict'):
                params['update_time'] = self.update_time.to_alipay_dict()
            else:
                params['update_time'] = self.update_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ShellCompanyGsChangeDetail()
        if 'after_content' in d:
            o.after_content = d['after_content']
        if 'before_content' in d:
            o.before_content = d['before_content']
        if 'change_type' in d:
            o.change_type = d['change_type']
        if 'description' in d:
            o.description = d['description']
        if 'title' in d:
            o.title = d['title']
        if 'update_time' in d:
            o.update_time = d['update_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AssetInfoCorrectionItem(object):

    def __init__(self):
        self._assign_item_id = None
        self._change_reason = None
        self._change_type = None
        self._item_id = None
        self._new_asset_value = None
        self._new_item_id = None
        self._original_asset_value = None
        self._original_supplier_id = None
        self._request_id = None

    @property
    def assign_item_id(self):
        return self._assign_item_id

    @assign_item_id.setter
    def assign_item_id(self, value):
        self._assign_item_id = value
    @property
    def change_reason(self):
        return self._change_reason

    @change_reason.setter
    def change_reason(self, value):
        self._change_reason = value
    @property
    def change_type(self):
        return self._change_type

    @change_type.setter
    def change_type(self, value):
        self._change_type = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def new_asset_value(self):
        return self._new_asset_value

    @new_asset_value.setter
    def new_asset_value(self, value):
        self._new_asset_value = value
    @property
    def new_item_id(self):
        return self._new_item_id

    @new_item_id.setter
    def new_item_id(self, value):
        self._new_item_id = value
    @property
    def original_asset_value(self):
        return self._original_asset_value

    @original_asset_value.setter
    def original_asset_value(self, value):
        self._original_asset_value = value
    @property
    def original_supplier_id(self):
        return self._original_supplier_id

    @original_supplier_id.setter
    def original_supplier_id(self, value):
        self._original_supplier_id = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.assign_item_id:
            if hasattr(self.assign_item_id, 'to_alipay_dict'):
                params['assign_item_id'] = self.assign_item_id.to_alipay_dict()
            else:
                params['assign_item_id'] = self.assign_item_id
        if self.change_reason:
            if hasattr(self.change_reason, 'to_alipay_dict'):
                params['change_reason'] = self.change_reason.to_alipay_dict()
            else:
                params['change_reason'] = self.change_reason
        if self.change_type:
            if hasattr(self.change_type, 'to_alipay_dict'):
                params['change_type'] = self.change_type.to_alipay_dict()
            else:
                params['change_type'] = self.change_type
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.new_asset_value:
            if hasattr(self.new_asset_value, 'to_alipay_dict'):
                params['new_asset_value'] = self.new_asset_value.to_alipay_dict()
            else:
                params['new_asset_value'] = self.new_asset_value
        if self.new_item_id:
            if hasattr(self.new_item_id, 'to_alipay_dict'):
                params['new_item_id'] = self.new_item_id.to_alipay_dict()
            else:
                params['new_item_id'] = self.new_item_id
        if self.original_asset_value:
            if hasattr(self.original_asset_value, 'to_alipay_dict'):
                params['original_asset_value'] = self.original_asset_value.to_alipay_dict()
            else:
                params['original_asset_value'] = self.original_asset_value
        if self.original_supplier_id:
            if hasattr(self.original_supplier_id, 'to_alipay_dict'):
                params['original_supplier_id'] = self.original_supplier_id.to_alipay_dict()
            else:
                params['original_supplier_id'] = self.original_supplier_id
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AssetInfoCorrectionItem()
        if 'assign_item_id' in d:
            o.assign_item_id = d['assign_item_id']
        if 'change_reason' in d:
            o.change_reason = d['change_reason']
        if 'change_type' in d:
            o.change_type = d['change_type']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'new_asset_value' in d:
            o.new_asset_value = d['new_asset_value']
        if 'new_item_id' in d:
            o.new_item_id = d['new_item_id']
        if 'original_asset_value' in d:
            o.original_asset_value = d['original_asset_value']
        if 'original_supplier_id' in d:
            o.original_supplier_id = d['original_supplier_id']
        if 'request_id' in d:
            o.request_id = d['request_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ExtraInfoVO(object):

    def __init__(self):
        self._maomao_friend = None
        self._maomao_register = None
        self._taobao_id = None

    @property
    def maomao_friend(self):
        return self._maomao_friend

    @maomao_friend.setter
    def maomao_friend(self, value):
        self._maomao_friend = value
    @property
    def maomao_register(self):
        return self._maomao_register

    @maomao_register.setter
    def maomao_register(self, value):
        self._maomao_register = value
    @property
    def taobao_id(self):
        return self._taobao_id

    @taobao_id.setter
    def taobao_id(self, value):
        self._taobao_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.maomao_friend:
            if hasattr(self.maomao_friend, 'to_alipay_dict'):
                params['maomao_friend'] = self.maomao_friend.to_alipay_dict()
            else:
                params['maomao_friend'] = self.maomao_friend
        if self.maomao_register:
            if hasattr(self.maomao_register, 'to_alipay_dict'):
                params['maomao_register'] = self.maomao_register.to_alipay_dict()
            else:
                params['maomao_register'] = self.maomao_register
        if self.taobao_id:
            if hasattr(self.taobao_id, 'to_alipay_dict'):
                params['taobao_id'] = self.taobao_id.to_alipay_dict()
            else:
                params['taobao_id'] = self.taobao_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ExtraInfoVO()
        if 'maomao_friend' in d:
            o.maomao_friend = d['maomao_friend']
        if 'maomao_register' in d:
            o.maomao_register = d['maomao_register']
        if 'taobao_id' in d:
            o.taobao_id = d['taobao_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayPcreditHuabeiPcbenefitcoreBfactivitfacadeQueryModel(object):

    def __init__(self):
        self._partner_id = None
        self._product_ids = None
        self._request_from = None
        self._status = None
        self._user_id = None

    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def product_ids(self):
        return self._product_ids

    @product_ids.setter
    def product_ids(self, value):
        if isinstance(value, list):
            self._product_ids = list()
            for i in value:
                self._product_ids.append(i)
    @property
    def request_from(self):
        return self._request_from

    @request_from.setter
    def request_from(self, value):
        self._request_from = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        if isinstance(value, list):
            self._status = list()
            for i in value:
                self._status.append(i)
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.product_ids:
            if isinstance(self.product_ids, list):
                for i in range(0, len(self.product_ids)):
                    element = self.product_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.product_ids[i] = element.to_alipay_dict()
            if hasattr(self.product_ids, 'to_alipay_dict'):
                params['product_ids'] = self.product_ids.to_alipay_dict()
            else:
                params['product_ids'] = self.product_ids
        if self.request_from:
            if hasattr(self.request_from, 'to_alipay_dict'):
                params['request_from'] = self.request_from.to_alipay_dict()
            else:
                params['request_from'] = self.request_from
        if self.status:
            if isinstance(self.status, list):
                for i in range(0, len(self.status)):
                    element = self.status[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.status[i] = element.to_alipay_dict()
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPcreditHuabeiPcbenefitcoreBfactivitfacadeQueryModel()
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'product_ids' in d:
            o.product_ids = d['product_ids']
        if 'request_from' in d:
            o.request_from = d['request_from']
        if 'status' in d:
            o.status = d['status']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundTransThirdpartyRewardQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundTransThirdpartyRewardQueryResponse, self).__init__()
        self._amount = None
        self._error_msg = None
        self._last_modified = None
        self._receiver_user_id = None
        self._sender_user_id = None
        self._status = None
        self._transfer_no = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def error_msg(self):
        return self._error_msg

    @error_msg.setter
    def error_msg(self, value):
        self._error_msg = value
    @property
    def last_modified(self):
        return self._last_modified

    @last_modified.setter
    def last_modified(self, value):
        self._last_modified = value
    @property
    def receiver_user_id(self):
        return self._receiver_user_id

    @receiver_user_id.setter
    def receiver_user_id(self, value):
        self._receiver_user_id = value
    @property
    def sender_user_id(self):
        return self._sender_user_id

    @sender_user_id.setter
    def sender_user_id(self, value):
        self._sender_user_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def transfer_no(self):
        return self._transfer_no

    @transfer_no.setter
    def transfer_no(self, value):
        self._transfer_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundTransThirdpartyRewardQueryResponse, self).parse_response_content(response_content)
        if 'amount' in response:
            self.amount = response['amount']
        if 'error_msg' in response:
            self.error_msg = response['error_msg']
        if 'last_modified' in response:
            self.last_modified = response['last_modified']
        if 'receiver_user_id' in response:
            self.receiver_user_id = response['receiver_user_id']
        if 'sender_user_id' in response:
            self.sender_user_id = response['sender_user_id']
        if 'status' in response:
            self.status = response['status']
        if 'transfer_no' in response:
            self.transfer_no = response['transfer_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class QrcodeEntity(object):

    def __init__(self):
        self._desk_id = None
        self._qrcode_id = None
        self._relation_id = None
        self._shop_id = None

    @property
    def desk_id(self):
        return self._desk_id

    @desk_id.setter
    def desk_id(self, value):
        self._desk_id = value
    @property
    def qrcode_id(self):
        return self._qrcode_id

    @qrcode_id.setter
    def qrcode_id(self, value):
        self._qrcode_id = value
    @property
    def relation_id(self):
        return self._relation_id

    @relation_id.setter
    def relation_id(self, value):
        self._relation_id = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.desk_id:
            if hasattr(self.desk_id, 'to_alipay_dict'):
                params['desk_id'] = self.desk_id.to_alipay_dict()
            else:
                params['desk_id'] = self.desk_id
        if self.qrcode_id:
            if hasattr(self.qrcode_id, 'to_alipay_dict'):
                params['qrcode_id'] = self.qrcode_id.to_alipay_dict()
            else:
                params['qrcode_id'] = self.qrcode_id
        if self.relation_id:
            if hasattr(self.relation_id, 'to_alipay_dict'):
                params['relation_id'] = self.relation_id.to_alipay_dict()
            else:
                params['relation_id'] = self.relation_id
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = QrcodeEntity()
        if 'desk_id' in d:
            o.desk_id = d['desk_id']
        if 'qrcode_id' in d:
            o.qrcode_id = d['qrcode_id']
        if 'relation_id' in d:
            o.relation_id = d['relation_id']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class HelloBikePriceResultItem(object):

    def __init__(self):
        self._card_type = None
        self._priority = None
        self._promo_price_cent = None

    @property
    def card_type(self):
        return self._card_type

    @card_type.setter
    def card_type(self, value):
        self._card_type = value
    @property
    def priority(self):
        return self._priority

    @priority.setter
    def priority(self, value):
        self._priority = value
    @property
    def promo_price_cent(self):
        return self._promo_price_cent

    @promo_price_cent.setter
    def promo_price_cent(self, value):
        self._promo_price_cent = value


    def to_alipay_dict(self):
        params = dict()
        if self.card_type:
            if hasattr(self.card_type, 'to_alipay_dict'):
                params['card_type'] = self.card_type.to_alipay_dict()
            else:
                params['card_type'] = self.card_type
        if self.priority:
            if hasattr(self.priority, 'to_alipay_dict'):
                params['priority'] = self.priority.to_alipay_dict()
            else:
                params['priority'] = self.priority
        if self.promo_price_cent:
            if hasattr(self.promo_price_cent, 'to_alipay_dict'):
                params['promo_price_cent'] = self.promo_price_cent.to_alipay_dict()
            else:
                params['promo_price_cent'] = self.promo_price_cent
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = HelloBikePriceResultItem()
        if 'card_type' in d:
            o.card_type = d['card_type']
        if 'priority' in d:
            o.priority = d['priority']
        if 'promo_price_cent' in d:
            o.promo_price_cent = d['promo_price_cent']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCreditEpDataapiMigrationQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditEpDataapiMigrationQueryResponse, self).__init__()
        self._content = None

    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditEpDataapiMigrationQueryResponse, self).parse_response_content(response_content)
        if 'content' in response:
            self.content = response['content']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySocialBaseChatGnameModifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySocialBaseChatGnameModifyResponse, self).__init__()
        self._result_modify = None

    @property
    def result_modify(self):
        return self._result_modify

    @result_modify.setter
    def result_modify(self, value):
        self._result_modify = value

    def parse_response_content(self, response_content):
        response = super(AlipaySocialBaseChatGnameModifyResponse, self).parse_response_content(response_content)
        if 'result_modify' in response:
            self.result_modify = response['result_modify']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayAssetPointPointprodBudgetlibModifyModel(object):

    def __init__(self):
        self._budget_code = None
        self._contract_pid = None
        self._end_time = None
        self._point_lib_id = None
        self._start_time = None

    @property
    def budget_code(self):
        return self._budget_code

    @budget_code.setter
    def budget_code(self, value):
        self._budget_code = value
    @property
    def contract_pid(self):
        return self._contract_pid

    @contract_pid.setter
    def contract_pid(self, value):
        self._contract_pid = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def point_lib_id(self):
        return self._point_lib_id

    @point_lib_id.setter
    def point_lib_id(self, value):
        self._point_lib_id = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.budget_code:
            if hasattr(self.budget_code, 'to_alipay_dict'):
                params['budget_code'] = self.budget_code.to_alipay_dict()
            else:
                params['budget_code'] = self.budget_code
        if self.contract_pid:
            if hasattr(self.contract_pid, 'to_alipay_dict'):
                params['contract_pid'] = self.contract_pid.to_alipay_dict()
            else:
                params['contract_pid'] = self.contract_pid
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.point_lib_id:
            if hasattr(self.point_lib_id, 'to_alipay_dict'):
                params['point_lib_id'] = self.point_lib_id.to_alipay_dict()
            else:
                params['point_lib_id'] = self.point_lib_id
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayAssetPointPointprodBudgetlibModifyModel()
        if 'budget_code' in d:
            o.budget_code = d['budget_code']
        if 'contract_pid' in d:
            o.contract_pid = d['contract_pid']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'point_lib_id' in d:
            o.point_lib_id = d['point_lib_id']
        if 'start_time' in d:
            o.start_time = d['start_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TradeApplyParams(object):

    def __init__(self):
        self._broker_id = None
        self._buyer_name = None
        self._currency = None
        self._expire_time = None
        self._out_trade_no = None
        self._promo_params = None
        self._subject = None
        self._total_amount = None

    @property
    def broker_id(self):
        return self._broker_id

    @broker_id.setter
    def broker_id(self, value):
        self._broker_id = value
    @property
    def buyer_name(self):
        return self._buyer_name

    @buyer_name.setter
    def buyer_name(self, value):
        self._buyer_name = value
    @property
    def currency(self):
        return self._currency

    @currency.setter
    def currency(self, value):
        self._currency = value
    @property
    def expire_time(self):
        return self._expire_time

    @expire_time.setter
    def expire_time(self, value):
        self._expire_time = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def promo_params(self):
        return self._promo_params

    @promo_params.setter
    def promo_params(self, value):
        self._promo_params = value
    @property
    def subject(self):
        return self._subject

    @subject.setter
    def subject(self, value):
        self._subject = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.broker_id:
            if hasattr(self.broker_id, 'to_alipay_dict'):
                params['broker_id'] = self.broker_id.to_alipay_dict()
            else:
                params['broker_id'] = self.broker_id
        if self.buyer_name:
            if hasattr(self.buyer_name, 'to_alipay_dict'):
                params['buyer_name'] = self.buyer_name.to_alipay_dict()
            else:
                params['buyer_name'] = self.buyer_name
        if self.currency:
            if hasattr(self.currency, 'to_alipay_dict'):
                params['currency'] = self.currency.to_alipay_dict()
            else:
                params['currency'] = self.currency
        if self.expire_time:
            if hasattr(self.expire_time, 'to_alipay_dict'):
                params['expire_time'] = self.expire_time.to_alipay_dict()
            else:
                params['expire_time'] = self.expire_time
        if self.out_trade_no:
            if hasattr(self.out_trade_no, 'to_alipay_dict'):
                params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
            else:
                params['out_trade_no'] = self.out_trade_no
        if self.promo_params:
            if hasattr(self.promo_params, 'to_alipay_dict'):
                params['promo_params'] = self.promo_params.to_alipay_dict()
            else:
                params['promo_params'] = self.promo_params
        if self.subject:
            if hasattr(self.subject, 'to_alipay_dict'):
                params['subject'] = self.subject.to_alipay_dict()
            else:
                params['subject'] = self.subject
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TradeApplyParams()
        if 'broker_id' in d:
            o.broker_id = d['broker_id']
        if 'buyer_name' in d:
            o.buyer_name = d['buyer_name']
        if 'currency' in d:
            o.currency = d['currency']
        if 'expire_time' in d:
            o.expire_time = d['expire_time']
        if 'out_trade_no' in d:
            o.out_trade_no = d['out_trade_no']
        if 'promo_params' in d:
            o.promo_params = d['promo_params']
        if 'subject' in d:
            o.subject = d['subject']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingDataDeerConnectorQueryModel(object):

    def __init__(self):
        self._connector_id = None
        self._params = None

    @property
    def connector_id(self):
        return self._connector_id

    @connector_id.setter
    def connector_id(self, value):
        self._connector_id = value
    @property
    def params(self):
        return self._params

    @params.setter
    def params(self, value):
        self._params = value


    def to_alipay_dict(self):
        params = dict()
        if self.connector_id:
            if hasattr(self.connector_id, 'to_alipay_dict'):
                params['connector_id'] = self.connector_id.to_alipay_dict()
            else:
                params['connector_id'] = self.connector_id
        if self.params:
            if hasattr(self.params, 'to_alipay_dict'):
                params['params'] = self.params.to_alipay_dict()
            else:
                params['params'] = self.params
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingDataDeerConnectorQueryModel()
        if 'connector_id' in d:
            o.connector_id = d['connector_id']
        if 'params' in d:
            o.params = d['params']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceTransportAuthBindingGetModel(object):

    def __init__(self):
        self._cert_no = None
        self._cert_type = None
        self._out_biz_no = None
        self._scene = None
        self._user_id = None

    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportAuthBindingGetModel()
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'scene' in d:
            o.scene = d['scene']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class UserIdentityExt(object):

    def __init__(self):
        self._account_issue_entity_id = None
        self._account_issue_entity_name = None
        self._account_name = None
        self._account_no = None
        self._ext_info = None
        self._inst_uuid = None
        self._inst_uuid_type = None
        self._member_id = None
        self._member_name = None

    @property
    def account_issue_entity_id(self):
        return self._account_issue_entity_id

    @account_issue_entity_id.setter
    def account_issue_entity_id(self, value):
        self._account_issue_entity_id = value
    @property
    def account_issue_entity_name(self):
        return self._account_issue_entity_name

    @account_issue_entity_name.setter
    def account_issue_entity_name(self, value):
        self._account_issue_entity_name = value
    @property
    def account_name(self):
        return self._account_name

    @account_name.setter
    def account_name(self, value):
        self._account_name = value
    @property
    def account_no(self):
        return self._account_no

    @account_no.setter
    def account_no(self, value):
        self._account_no = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def inst_uuid(self):
        return self._inst_uuid

    @inst_uuid.setter
    def inst_uuid(self, value):
        self._inst_uuid = value
    @property
    def inst_uuid_type(self):
        return self._inst_uuid_type

    @inst_uuid_type.setter
    def inst_uuid_type(self, value):
        self._inst_uuid_type = value
    @property
    def member_id(self):
        return self._member_id

    @member_id.setter
    def member_id(self, value):
        self._member_id = value
    @property
    def member_name(self):
        return self._member_name

    @member_name.setter
    def member_name(self, value):
        self._member_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_issue_entity_id:
            if hasattr(self.account_issue_entity_id, 'to_alipay_dict'):
                params['account_issue_entity_id'] = self.account_issue_entity_id.to_alipay_dict()
            else:
                params['account_issue_entity_id'] = self.account_issue_entity_id
        if self.account_issue_entity_name:
            if hasattr(self.account_issue_entity_name, 'to_alipay_dict'):
                params['account_issue_entity_name'] = self.account_issue_entity_name.to_alipay_dict()
            else:
                params['account_issue_entity_name'] = self.account_issue_entity_name
        if self.account_name:
            if hasattr(self.account_name, 'to_alipay_dict'):
                params['account_name'] = self.account_name.to_alipay_dict()
            else:
                params['account_name'] = self.account_name
        if self.account_no:
            if hasattr(self.account_no, 'to_alipay_dict'):
                params['account_no'] = self.account_no.to_alipay_dict()
            else:
                params['account_no'] = self.account_no
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.inst_uuid:
            if hasattr(self.inst_uuid, 'to_alipay_dict'):
                params['inst_uuid'] = self.inst_uuid.to_alipay_dict()
            else:
                params['inst_uuid'] = self.inst_uuid
        if self.inst_uuid_type:
            if hasattr(self.inst_uuid_type, 'to_alipay_dict'):
                params['inst_uuid_type'] = self.inst_uuid_type.to_alipay_dict()
            else:
                params['inst_uuid_type'] = self.inst_uuid_type
        if self.member_id:
            if hasattr(self.member_id, 'to_alipay_dict'):
                params['member_id'] = self.member_id.to_alipay_dict()
            else:
                params['member_id'] = self.member_id
        if self.member_name:
            if hasattr(self.member_name, 'to_alipay_dict'):
                params['member_name'] = self.member_name.to_alipay_dict()
            else:
                params['member_name'] = self.member_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = UserIdentityExt()
        if 'account_issue_entity_id' in d:
            o.account_issue_entity_id = d['account_issue_entity_id']
        if 'account_issue_entity_name' in d:
            o.account_issue_entity_name = d['account_issue_entity_name']
        if 'account_name' in d:
            o.account_name = d['account_name']
        if 'account_no' in d:
            o.account_no = d['account_no']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'inst_uuid' in d:
            o.inst_uuid = d['inst_uuid']
        if 'inst_uuid_type' in d:
            o.inst_uuid_type = d['inst_uuid_type']
        if 'member_id' in d:
            o.member_id = d['member_id']
        if 'member_name' in d:
            o.member_name = d['member_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoEduKtParentQueryModel(object):

    def __init__(self):
        self._child_name = None
        self._partner_id = None
        self._school_no = None
        self._school_pid = None
        self._student_code = None
        self._student_identify = None
        self._user_mobile = None

    @property
    def child_name(self):
        return self._child_name

    @child_name.setter
    def child_name(self, value):
        self._child_name = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def school_no(self):
        return self._school_no

    @school_no.setter
    def school_no(self, value):
        self._school_no = value
    @property
    def school_pid(self):
        return self._school_pid

    @school_pid.setter
    def school_pid(self, value):
        self._school_pid = value
    @property
    def student_code(self):
        return self._student_code

    @student_code.setter
    def student_code(self, value):
        self._student_code = value
    @property
    def student_identify(self):
        return self._student_identify

    @student_identify.setter
    def student_identify(self, value):
        self._student_identify = value
    @property
    def user_mobile(self):
        return self._user_mobile

    @user_mobile.setter
    def user_mobile(self, value):
        self._user_mobile = value


    def to_alipay_dict(self):
        params = dict()
        if self.child_name:
            if hasattr(self.child_name, 'to_alipay_dict'):
                params['child_name'] = self.child_name.to_alipay_dict()
            else:
                params['child_name'] = self.child_name
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.school_no:
            if hasattr(self.school_no, 'to_alipay_dict'):
                params['school_no'] = self.school_no.to_alipay_dict()
            else:
                params['school_no'] = self.school_no
        if self.school_pid:
            if hasattr(self.school_pid, 'to_alipay_dict'):
                params['school_pid'] = self.school_pid.to_alipay_dict()
            else:
                params['school_pid'] = self.school_pid
        if self.student_code:
            if hasattr(self.student_code, 'to_alipay_dict'):
                params['student_code'] = self.student_code.to_alipay_dict()
            else:
                params['student_code'] = self.student_code
        if self.student_identify:
            if hasattr(self.student_identify, 'to_alipay_dict'):
                params['student_identify'] = self.student_identify.to_alipay_dict()
            else:
                params['student_identify'] = self.student_identify
        if self.user_mobile:
            if hasattr(self.user_mobile, 'to_alipay_dict'):
                params['user_mobile'] = self.user_mobile.to_alipay_dict()
            else:
                params['user_mobile'] = self.user_mobile
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoEduKtParentQueryModel()
        if 'child_name' in d:
            o.child_name = d['child_name']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'school_no' in d:
            o.school_no = d['school_no']
        if 'school_pid' in d:
            o.school_pid = d['school_pid']
        if 'student_code' in d:
            o.student_code = d['student_code']
        if 'student_identify' in d:
            o.student_identify = d['student_identify']
        if 'user_mobile' in d:
            o.user_mobile = d['user_mobile']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.KbdishVirtualDishInfo import KbdishVirtualDishInfo


class KoubeiCateringDishVirtualdishQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiCateringDishVirtualdishQueryResponse, self).__init__()
        self._dish_list = None
        self._shop_id = None

    @property
    def dish_list(self):
        return self._dish_list

    @dish_list.setter
    def dish_list(self, value):
        if isinstance(value, list):
            self._dish_list = list()
            for i in value:
                if isinstance(i, KbdishVirtualDishInfo):
                    self._dish_list.append(i)
                else:
                    self._dish_list.append(KbdishVirtualDishInfo.from_alipay_dict(i))
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value

    def parse_response_content(self, response_content):
        response = super(KoubeiCateringDishVirtualdishQueryResponse, self).parse_response_content(response_content)
        if 'dish_list' in response:
            self.dish_list = response['dish_list']
        if 'shop_id' in response:
            self.shop_id = response['shop_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RepayPlanTermVO(object):

    def __init__(self):
        self._int_bal = None
        self._ovd_int_penalty_bal = None
        self._ovd_prin_penalty_bal = None
        self._paid_int_amt = None
        self._paid_ovd_int_penalty_amt = None
        self._paid_ovd_prin_penalty_amt = None
        self._paid_prin_amt = None
        self._prin_bal = None
        self._repay_amt_total = None
        self._status = None
        self._term_end_date = None
        self._term_no = None

    @property
    def int_bal(self):
        return self._int_bal

    @int_bal.setter
    def int_bal(self, value):
        self._int_bal = value
    @property
    def ovd_int_penalty_bal(self):
        return self._ovd_int_penalty_bal

    @ovd_int_penalty_bal.setter
    def ovd_int_penalty_bal(self, value):
        self._ovd_int_penalty_bal = value
    @property
    def ovd_prin_penalty_bal(self):
        return self._ovd_prin_penalty_bal

    @ovd_prin_penalty_bal.setter
    def ovd_prin_penalty_bal(self, value):
        self._ovd_prin_penalty_bal = value
    @property
    def paid_int_amt(self):
        return self._paid_int_amt

    @paid_int_amt.setter
    def paid_int_amt(self, value):
        self._paid_int_amt = value
    @property
    def paid_ovd_int_penalty_amt(self):
        return self._paid_ovd_int_penalty_amt

    @paid_ovd_int_penalty_amt.setter
    def paid_ovd_int_penalty_amt(self, value):
        self._paid_ovd_int_penalty_amt = value
    @property
    def paid_ovd_prin_penalty_amt(self):
        return self._paid_ovd_prin_penalty_amt

    @paid_ovd_prin_penalty_amt.setter
    def paid_ovd_prin_penalty_amt(self, value):
        self._paid_ovd_prin_penalty_amt = value
    @property
    def paid_prin_amt(self):
        return self._paid_prin_amt

    @paid_prin_amt.setter
    def paid_prin_amt(self, value):
        self._paid_prin_amt = value
    @property
    def prin_bal(self):
        return self._prin_bal

    @prin_bal.setter
    def prin_bal(self, value):
        self._prin_bal = value
    @property
    def repay_amt_total(self):
        return self._repay_amt_total

    @repay_amt_total.setter
    def repay_amt_total(self, value):
        self._repay_amt_total = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def term_end_date(self):
        return self._term_end_date

    @term_end_date.setter
    def term_end_date(self, value):
        self._term_end_date = value
    @property
    def term_no(self):
        return self._term_no

    @term_no.setter
    def term_no(self, value):
        self._term_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.int_bal:
            if hasattr(self.int_bal, 'to_alipay_dict'):
                params['int_bal'] = self.int_bal.to_alipay_dict()
            else:
                params['int_bal'] = self.int_bal
        if self.ovd_int_penalty_bal:
            if hasattr(self.ovd_int_penalty_bal, 'to_alipay_dict'):
                params['ovd_int_penalty_bal'] = self.ovd_int_penalty_bal.to_alipay_dict()
            else:
                params['ovd_int_penalty_bal'] = self.ovd_int_penalty_bal
        if self.ovd_prin_penalty_bal:
            if hasattr(self.ovd_prin_penalty_bal, 'to_alipay_dict'):
                params['ovd_prin_penalty_bal'] = self.ovd_prin_penalty_bal.to_alipay_dict()
            else:
                params['ovd_prin_penalty_bal'] = self.ovd_prin_penalty_bal
        if self.paid_int_amt:
            if hasattr(self.paid_int_amt, 'to_alipay_dict'):
                params['paid_int_amt'] = self.paid_int_amt.to_alipay_dict()
            else:
                params['paid_int_amt'] = self.paid_int_amt
        if self.paid_ovd_int_penalty_amt:
            if hasattr(self.paid_ovd_int_penalty_amt, 'to_alipay_dict'):
                params['paid_ovd_int_penalty_amt'] = self.paid_ovd_int_penalty_amt.to_alipay_dict()
            else:
                params['paid_ovd_int_penalty_amt'] = self.paid_ovd_int_penalty_amt
        if self.paid_ovd_prin_penalty_amt:
            if hasattr(self.paid_ovd_prin_penalty_amt, 'to_alipay_dict'):
                params['paid_ovd_prin_penalty_amt'] = self.paid_ovd_prin_penalty_amt.to_alipay_dict()
            else:
                params['paid_ovd_prin_penalty_amt'] = self.paid_ovd_prin_penalty_amt
        if self.paid_prin_amt:
            if hasattr(self.paid_prin_amt, 'to_alipay_dict'):
                params['paid_prin_amt'] = self.paid_prin_amt.to_alipay_dict()
            else:
                params['paid_prin_amt'] = self.paid_prin_amt
        if self.prin_bal:
            if hasattr(self.prin_bal, 'to_alipay_dict'):
                params['prin_bal'] = self.prin_bal.to_alipay_dict()
            else:
                params['prin_bal'] = self.prin_bal
        if self.repay_amt_total:
            if hasattr(self.repay_amt_total, 'to_alipay_dict'):
                params['repay_amt_total'] = self.repay_amt_total.to_alipay_dict()
            else:
                params['repay_amt_total'] = self.repay_amt_total
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.term_end_date:
            if hasattr(self.term_end_date, 'to_alipay_dict'):
                params['term_end_date'] = self.term_end_date.to_alipay_dict()
            else:
                params['term_end_date'] = self.term_end_date
        if self.term_no:
            if hasattr(self.term_no, 'to_alipay_dict'):
                params['term_no'] = self.term_no.to_alipay_dict()
            else:
                params['term_no'] = self.term_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RepayPlanTermVO()
        if 'int_bal' in d:
            o.int_bal = d['int_bal']
        if 'ovd_int_penalty_bal' in d:
            o.ovd_int_penalty_bal = d['ovd_int_penalty_bal']
        if 'ovd_prin_penalty_bal' in d:
            o.ovd_prin_penalty_bal = d['ovd_prin_penalty_bal']
        if 'paid_int_amt' in d:
            o.paid_int_amt = d['paid_int_amt']
        if 'paid_ovd_int_penalty_amt' in d:
            o.paid_ovd_int_penalty_amt = d['paid_ovd_int_penalty_amt']
        if 'paid_ovd_prin_penalty_amt' in d:
            o.paid_ovd_prin_penalty_amt = d['paid_ovd_prin_penalty_amt']
        if 'paid_prin_amt' in d:
            o.paid_prin_amt = d['paid_prin_amt']
        if 'prin_bal' in d:
            o.prin_bal = d['prin_bal']
        if 'repay_amt_total' in d:
            o.repay_amt_total = d['repay_amt_total']
        if 'status' in d:
            o.status = d['status']
        if 'term_end_date' in d:
            o.term_end_date = d['term_end_date']
        if 'term_no' in d:
            o.term_no = d['term_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class LinkTypeResult(object):

    def __init__(self):
        self._level = None
        self._link_type_code = None
        self._link_type_name = None
        self._parent_code = None
        self._state = None
        self._tnt_inst_id = None

    @property
    def level(self):
        return self._level

    @level.setter
    def level(self, value):
        self._level = value
    @property
    def link_type_code(self):
        return self._link_type_code

    @link_type_code.setter
    def link_type_code(self, value):
        self._link_type_code = value
    @property
    def link_type_name(self):
        return self._link_type_name

    @link_type_name.setter
    def link_type_name(self, value):
        self._link_type_name = value
    @property
    def parent_code(self):
        return self._parent_code

    @parent_code.setter
    def parent_code(self, value):
        self._parent_code = value
    @property
    def state(self):
        return self._state

    @state.setter
    def state(self, value):
        self._state = value
    @property
    def tnt_inst_id(self):
        return self._tnt_inst_id

    @tnt_inst_id.setter
    def tnt_inst_id(self, value):
        self._tnt_inst_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.level:
            if hasattr(self.level, 'to_alipay_dict'):
                params['level'] = self.level.to_alipay_dict()
            else:
                params['level'] = self.level
        if self.link_type_code:
            if hasattr(self.link_type_code, 'to_alipay_dict'):
                params['link_type_code'] = self.link_type_code.to_alipay_dict()
            else:
                params['link_type_code'] = self.link_type_code
        if self.link_type_name:
            if hasattr(self.link_type_name, 'to_alipay_dict'):
                params['link_type_name'] = self.link_type_name.to_alipay_dict()
            else:
                params['link_type_name'] = self.link_type_name
        if self.parent_code:
            if hasattr(self.parent_code, 'to_alipay_dict'):
                params['parent_code'] = self.parent_code.to_alipay_dict()
            else:
                params['parent_code'] = self.parent_code
        if self.state:
            if hasattr(self.state, 'to_alipay_dict'):
                params['state'] = self.state.to_alipay_dict()
            else:
                params['state'] = self.state
        if self.tnt_inst_id:
            if hasattr(self.tnt_inst_id, 'to_alipay_dict'):
                params['tnt_inst_id'] = self.tnt_inst_id.to_alipay_dict()
            else:
                params['tnt_inst_id'] = self.tnt_inst_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = LinkTypeResult()
        if 'level' in d:
            o.level = d['level']
        if 'link_type_code' in d:
            o.link_type_code = d['link_type_code']
        if 'link_type_name' in d:
            o.link_type_name = d['link_type_name']
        if 'parent_code' in d:
            o.parent_code = d['parent_code']
        if 'state' in d:
            o.state = d['state']
        if 'tnt_inst_id' in d:
            o.tnt_inst_id = d['tnt_inst_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ActivityGoodsStockIncrease(object):

    def __init__(self):
        self._barcode = None
        self._benefit_id = None
        self._increase_stock = None

    @property
    def barcode(self):
        return self._barcode

    @barcode.setter
    def barcode(self, value):
        self._barcode = value
    @property
    def benefit_id(self):
        return self._benefit_id

    @benefit_id.setter
    def benefit_id(self, value):
        self._benefit_id = value
    @property
    def increase_stock(self):
        return self._increase_stock

    @increase_stock.setter
    def increase_stock(self, value):
        self._increase_stock = value


    def to_alipay_dict(self):
        params = dict()
        if self.barcode:
            if hasattr(self.barcode, 'to_alipay_dict'):
                params['barcode'] = self.barcode.to_alipay_dict()
            else:
                params['barcode'] = self.barcode
        if self.benefit_id:
            if hasattr(self.benefit_id, 'to_alipay_dict'):
                params['benefit_id'] = self.benefit_id.to_alipay_dict()
            else:
                params['benefit_id'] = self.benefit_id
        if self.increase_stock:
            if hasattr(self.increase_stock, 'to_alipay_dict'):
                params['increase_stock'] = self.increase_stock.to_alipay_dict()
            else:
                params['increase_stock'] = self.increase_stock
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ActivityGoodsStockIncrease()
        if 'barcode' in d:
            o.barcode = d['barcode']
        if 'benefit_id' in d:
            o.benefit_id = d['benefit_id']
        if 'increase_stock' in d:
            o.increase_stock = d['increase_stock']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.HighwaySceneData import HighwaySceneData


class AlipayCommerceTransportEtcTripSyncModel(object):

    def __init__(self):
        self._highway_data = None
        self._out_trade_no = None
        self._plate_color = None
        self._plate_no = None
        self._seller_id = None
        self._total_amount = None
        self._trade_no = None
        self._trade_status = None
        self._uid = None

    @property
    def highway_data(self):
        return self._highway_data

    @highway_data.setter
    def highway_data(self, value):
        if isinstance(value, HighwaySceneData):
            self._highway_data = value
        else:
            self._highway_data = HighwaySceneData.from_alipay_dict(value)
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def plate_color(self):
        return self._plate_color

    @plate_color.setter
    def plate_color(self, value):
        self._plate_color = value
    @property
    def plate_no(self):
        return self._plate_no

    @plate_no.setter
    def plate_no(self, value):
        self._plate_no = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def trade_status(self):
        return self._trade_status

    @trade_status.setter
    def trade_status(self, value):
        self._trade_status = value
    @property
    def uid(self):
        return self._uid

    @uid.setter
    def uid(self, value):
        self._uid = value


    def to_alipay_dict(self):
        params = dict()
        if self.highway_data:
            if hasattr(self.highway_data, 'to_alipay_dict'):
                params['highway_data'] = self.highway_data.to_alipay_dict()
            else:
                params['highway_data'] = self.highway_data
        if self.out_trade_no:
            if hasattr(self.out_trade_no, 'to_alipay_dict'):
                params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
            else:
                params['out_trade_no'] = self.out_trade_no
        if self.plate_color:
            if hasattr(self.plate_color, 'to_alipay_dict'):
                params['plate_color'] = self.plate_color.to_alipay_dict()
            else:
                params['plate_color'] = self.plate_color
        if self.plate_no:
            if hasattr(self.plate_no, 'to_alipay_dict'):
                params['plate_no'] = self.plate_no.to_alipay_dict()
            else:
                params['plate_no'] = self.plate_no
        if self.seller_id:
            if hasattr(self.seller_id, 'to_alipay_dict'):
                params['seller_id'] = self.seller_id.to_alipay_dict()
            else:
                params['seller_id'] = self.seller_id
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        if self.trade_status:
            if hasattr(self.trade_status, 'to_alipay_dict'):
                params['trade_status'] = self.trade_status.to_alipay_dict()
            else:
                params['trade_status'] = self.trade_status
        if self.uid:
            if hasattr(self.uid, 'to_alipay_dict'):
                params['uid'] = self.uid.to_alipay_dict()
            else:
                params['uid'] = self.uid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportEtcTripSyncModel()
        if 'highway_data' in d:
            o.highway_data = d['highway_data']
        if 'out_trade_no' in d:
            o.out_trade_no = d['out_trade_no']
        if 'plate_color' in d:
            o.plate_color = d['plate_color']
        if 'plate_no' in d:
            o.plate_no = d['plate_no']
        if 'seller_id' in d:
            o.seller_id = d['seller_id']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        if 'trade_status' in d:
            o.trade_status = d['trade_status']
        if 'uid' in d:
            o.uid = d['uid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class VoucherVO(object):

    def __init__(self):
        self._gmt_active = None
        self._gmt_expired = None
        self._name = None
        self._threshold_amount = None
        self._total_amount = None
        self._voucher_id = None
        self._voucher_template_id = None

    @property
    def gmt_active(self):
        return self._gmt_active

    @gmt_active.setter
    def gmt_active(self, value):
        self._gmt_active = value
    @property
    def gmt_expired(self):
        return self._gmt_expired

    @gmt_expired.setter
    def gmt_expired(self, value):
        self._gmt_expired = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def threshold_amount(self):
        return self._threshold_amount

    @threshold_amount.setter
    def threshold_amount(self, value):
        self._threshold_amount = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value
    @property
    def voucher_id(self):
        return self._voucher_id

    @voucher_id.setter
    def voucher_id(self, value):
        self._voucher_id = value
    @property
    def voucher_template_id(self):
        return self._voucher_template_id

    @voucher_template_id.setter
    def voucher_template_id(self, value):
        self._voucher_template_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.gmt_active:
            if hasattr(self.gmt_active, 'to_alipay_dict'):
                params['gmt_active'] = self.gmt_active.to_alipay_dict()
            else:
                params['gmt_active'] = self.gmt_active
        if self.gmt_expired:
            if hasattr(self.gmt_expired, 'to_alipay_dict'):
                params['gmt_expired'] = self.gmt_expired.to_alipay_dict()
            else:
                params['gmt_expired'] = self.gmt_expired
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.threshold_amount:
            if hasattr(self.threshold_amount, 'to_alipay_dict'):
                params['threshold_amount'] = self.threshold_amount.to_alipay_dict()
            else:
                params['threshold_amount'] = self.threshold_amount
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        if self.voucher_id:
            if hasattr(self.voucher_id, 'to_alipay_dict'):
                params['voucher_id'] = self.voucher_id.to_alipay_dict()
            else:
                params['voucher_id'] = self.voucher_id
        if self.voucher_template_id:
            if hasattr(self.voucher_template_id, 'to_alipay_dict'):
                params['voucher_template_id'] = self.voucher_template_id.to_alipay_dict()
            else:
                params['voucher_template_id'] = self.voucher_template_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherVO()
        if 'gmt_active' in d:
            o.gmt_active = d['gmt_active']
        if 'gmt_expired' in d:
            o.gmt_expired = d['gmt_expired']
        if 'name' in d:
            o.name = d['name']
        if 'threshold_amount' in d:
            o.threshold_amount = d['threshold_amount']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        if 'voucher_id' in d:
            o.voucher_id = d['voucher_id']
        if 'voucher_template_id' in d:
            o.voucher_template_id = d['voucher_template_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.CPBillResultSet import CPBillResultSet


class AlipayEcoCplifeBillBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoCplifeBillBatchqueryResponse, self).__init__()
        self._bill_result_set = None
        self._current_page_num = None
        self._total_bill_count = None

    @property
    def bill_result_set(self):
        return self._bill_result_set

    @bill_result_set.setter
    def bill_result_set(self, value):
        if isinstance(value, list):
            self._bill_result_set = list()
            for i in value:
                if isinstance(i, CPBillResultSet):
                    self._bill_result_set.append(i)
                else:
                    self._bill_result_set.append(CPBillResultSet.from_alipay_dict(i))
    @property
    def current_page_num(self):
        return self._current_page_num

    @current_page_num.setter
    def current_page_num(self, value):
        self._current_page_num = value
    @property
    def total_bill_count(self):
        return self._total_bill_count

    @total_bill_count.setter
    def total_bill_count(self, value):
        self._total_bill_count = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoCplifeBillBatchqueryResponse, self).parse_response_content(response_content)
        if 'bill_result_set' in response:
            self.bill_result_set = response['bill_result_set']
        if 'current_page_num' in response:
            self.current_page_num = response['current_page_num']
        if 'total_bill_count' in response:
            self.total_bill_count = response['total_bill_count']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenMiniMorphoAppCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniMorphoAppCreateResponse, self).__init__()
        self._id = None
        self._mini_app_id = None

    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniMorphoAppCreateResponse, self).parse_response_content(response_content)
        if 'id' in response:
            self.id = response['id']
        if 'mini_app_id' in response:
            self.mini_app_id = response['mini_app_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BookInfoModify(object):

    def __init__(self):
        self._book_table_position = None
        self._book_timeout = None

    @property
    def book_table_position(self):
        return self._book_table_position

    @book_table_position.setter
    def book_table_position(self, value):
        self._book_table_position = value
    @property
    def book_timeout(self):
        return self._book_timeout

    @book_timeout.setter
    def book_timeout(self, value):
        self._book_timeout = value


    def to_alipay_dict(self):
        params = dict()
        if self.book_table_position:
            if hasattr(self.book_table_position, 'to_alipay_dict'):
                params['book_table_position'] = self.book_table_position.to_alipay_dict()
            else:
                params['book_table_position'] = self.book_table_position
        if self.book_timeout:
            if hasattr(self.book_timeout, 'to_alipay_dict'):
                params['book_timeout'] = self.book_timeout.to_alipay_dict()
            else:
                params['book_timeout'] = self.book_timeout
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BookInfoModify()
        if 'book_table_position' in d:
            o.book_table_position = d['book_table_position']
        if 'book_timeout' in d:
            o.book_timeout = d['book_timeout']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankCreditUserSitememberEnterpriseMatchModel(object):

    def __init__(self):
        self._business_reg_no = None
        self._company_name = None
        self._site = None
        self._site_login_id = None
        self._social_credit_code = None

    @property
    def business_reg_no(self):
        return self._business_reg_no

    @business_reg_no.setter
    def business_reg_no(self, value):
        self._business_reg_no = value
    @property
    def company_name(self):
        return self._company_name

    @company_name.setter
    def company_name(self, value):
        self._company_name = value
    @property
    def site(self):
        return self._site

    @site.setter
    def site(self, value):
        self._site = value
    @property
    def site_login_id(self):
        return self._site_login_id

    @site_login_id.setter
    def site_login_id(self, value):
        self._site_login_id = value
    @property
    def social_credit_code(self):
        return self._social_credit_code

    @social_credit_code.setter
    def social_credit_code(self, value):
        self._social_credit_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.business_reg_no:
            if hasattr(self.business_reg_no, 'to_alipay_dict'):
                params['business_reg_no'] = self.business_reg_no.to_alipay_dict()
            else:
                params['business_reg_no'] = self.business_reg_no
        if self.company_name:
            if hasattr(self.company_name, 'to_alipay_dict'):
                params['company_name'] = self.company_name.to_alipay_dict()
            else:
                params['company_name'] = self.company_name
        if self.site:
            if hasattr(self.site, 'to_alipay_dict'):
                params['site'] = self.site.to_alipay_dict()
            else:
                params['site'] = self.site
        if self.site_login_id:
            if hasattr(self.site_login_id, 'to_alipay_dict'):
                params['site_login_id'] = self.site_login_id.to_alipay_dict()
            else:
                params['site_login_id'] = self.site_login_id
        if self.social_credit_code:
            if hasattr(self.social_credit_code, 'to_alipay_dict'):
                params['social_credit_code'] = self.social_credit_code.to_alipay_dict()
            else:
                params['social_credit_code'] = self.social_credit_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditUserSitememberEnterpriseMatchModel()
        if 'business_reg_no' in d:
            o.business_reg_no = d['business_reg_no']
        if 'company_name' in d:
            o.company_name = d['company_name']
        if 'site' in d:
            o.site = d['site']
        if 'site_login_id' in d:
            o.site_login_id = d['site_login_id']
        if 'social_credit_code' in d:
            o.social_credit_code = d['social_credit_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceIotDeviceBindQueryModel(object):

    def __init__(self):
        self._app_type = None
        self._application_id = None
        self._biz_tid = None
        self._device_id_type = None
        self._device_sn = None
        self._mini_app_id = None
        self._supplier_id = None

    @property
    def app_type(self):
        return self._app_type

    @app_type.setter
    def app_type(self, value):
        self._app_type = value
    @property
    def application_id(self):
        return self._application_id

    @application_id.setter
    def application_id(self, value):
        self._application_id = value
    @property
    def biz_tid(self):
        return self._biz_tid

    @biz_tid.setter
    def biz_tid(self, value):
        self._biz_tid = value
    @property
    def device_id_type(self):
        return self._device_id_type

    @device_id_type.setter
    def device_id_type(self, value):
        self._device_id_type = value
    @property
    def device_sn(self):
        return self._device_sn

    @device_sn.setter
    def device_sn(self, value):
        self._device_sn = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def supplier_id(self):
        return self._supplier_id

    @supplier_id.setter
    def supplier_id(self, value):
        self._supplier_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_type:
            if hasattr(self.app_type, 'to_alipay_dict'):
                params['app_type'] = self.app_type.to_alipay_dict()
            else:
                params['app_type'] = self.app_type
        if self.application_id:
            if hasattr(self.application_id, 'to_alipay_dict'):
                params['application_id'] = self.application_id.to_alipay_dict()
            else:
                params['application_id'] = self.application_id
        if self.biz_tid:
            if hasattr(self.biz_tid, 'to_alipay_dict'):
                params['biz_tid'] = self.biz_tid.to_alipay_dict()
            else:
                params['biz_tid'] = self.biz_tid
        if self.device_id_type:
            if hasattr(self.device_id_type, 'to_alipay_dict'):
                params['device_id_type'] = self.device_id_type.to_alipay_dict()
            else:
                params['device_id_type'] = self.device_id_type
        if self.device_sn:
            if hasattr(self.device_sn, 'to_alipay_dict'):
                params['device_sn'] = self.device_sn.to_alipay_dict()
            else:
                params['device_sn'] = self.device_sn
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.supplier_id:
            if hasattr(self.supplier_id, 'to_alipay_dict'):
                params['supplier_id'] = self.supplier_id.to_alipay_dict()
            else:
                params['supplier_id'] = self.supplier_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceIotDeviceBindQueryModel()
        if 'app_type' in d:
            o.app_type = d['app_type']
        if 'application_id' in d:
            o.application_id = d['application_id']
        if 'biz_tid' in d:
            o.biz_tid = d['biz_tid']
        if 'device_id_type' in d:
            o.device_id_type = d['device_id_type']
        if 'device_sn' in d:
            o.device_sn = d['device_sn']
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'supplier_id' in d:
            o.supplier_id = d['supplier_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMsaasMediarecogMmtcaftscvPicvideoQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMsaasMediarecogMmtcaftscvPicvideoQueryResponse, self).__init__()
        self._data = None
        self._request_id = None
        self._result = None
        self._transaction_id = None
        self._type = None

    @property
    def data(self):
        return self._data

    @data.setter
    def data(self, value):
        self._data = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def result(self):
        return self._result

    @result.setter
    def result(self, value):
        self._result = value
    @property
    def transaction_id(self):
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, value):
        self._transaction_id = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value

    def parse_response_content(self, response_content):
        response = super(AlipayMsaasMediarecogMmtcaftscvPicvideoQueryResponse, self).parse_response_content(response_content)
        if 'data' in response:
            self.data = response['data']
        if 'request_id' in response:
            self.request_id = response['request_id']
        if 'result' in response:
            self.result = response['result']
        if 'transaction_id' in response:
            self.transaction_id = response['transaction_id']
        if 'type' in response:
            self.type = response['type']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppPdeductSignQueryModel(object):

    def __init__(self):
        self._agreement_id = None
        self._bill_key = None
        self._biz_type = None
        self._charge_inst = None
        self._sub_biz_type = None
        self._user_id = None

    @property
    def agreement_id(self):
        return self._agreement_id

    @agreement_id.setter
    def agreement_id(self, value):
        self._agreement_id = value
    @property
    def bill_key(self):
        return self._bill_key

    @bill_key.setter
    def bill_key(self, value):
        self._bill_key = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def charge_inst(self):
        return self._charge_inst

    @charge_inst.setter
    def charge_inst(self, value):
        self._charge_inst = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_id:
            if hasattr(self.agreement_id, 'to_alipay_dict'):
                params['agreement_id'] = self.agreement_id.to_alipay_dict()
            else:
                params['agreement_id'] = self.agreement_id
        if self.bill_key:
            if hasattr(self.bill_key, 'to_alipay_dict'):
                params['bill_key'] = self.bill_key.to_alipay_dict()
            else:
                params['bill_key'] = self.bill_key
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.charge_inst:
            if hasattr(self.charge_inst, 'to_alipay_dict'):
                params['charge_inst'] = self.charge_inst.to_alipay_dict()
            else:
                params['charge_inst'] = self.charge_inst
        if self.sub_biz_type:
            if hasattr(self.sub_biz_type, 'to_alipay_dict'):
                params['sub_biz_type'] = self.sub_biz_type.to_alipay_dict()
            else:
                params['sub_biz_type'] = self.sub_biz_type
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppPdeductSignQueryModel()
        if 'agreement_id' in d:
            o.agreement_id = d['agreement_id']
        if 'bill_key' in d:
            o.bill_key = d['bill_key']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'charge_inst' in d:
            o.charge_inst = d['charge_inst']
        if 'sub_biz_type' in d:
            o.sub_biz_type = d['sub_biz_type']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o


